<?php
include ("axi_version.php");
function __autoload($class_name) {
    require_once 'axi_' . $class_name . '.php';
}
/**
 * This object is the primary object for this wrapper; it establishes the connection to Axigen and from the resulting object you will be able to access all other objects
 * @note this object must be initialized first
 * \defgroup cliobject CLI Object
 * @{
 */
class Axigen {
    private $session, $domains, $domainsName, $domainsLocation, $aacl, $server, $queue, $createdomain, $createsubdomain, $licenseObj;

    public function __construct() {
        check_version();
    }
    public function __destruct() {
        $this->disconnect();
    }

    /** 
    * close connection with the server
    * @note the connection with the server is closed on object destroy, so you don't need to explicit call disconnect
    */
    public function disconnect() {
        if (!is_null($this->session)) {
            session_close($this->session);
            $this->session = null;
        }
    }
    /**                 
     * this method is used to connect to the Axigen CLI
     * @note please make sure that you have set the CLI listener to be able to connect to the place you run the script from
     * @note if you request a secure connection the Axigen server CLI listener must be SSL enabled
     * @note if the SSL connection to the provided endpoint fails (e.g. because the endpoint is not SSL enabled) cliclient will attempt to connect to without SSL
     * @return bool
     * @param $ip string Axigen server ip address
     * @param $port int Axigen server CLI port (default 7000)
     * @param $username string admin username
     * @param $password string admin password
     * @param $secure bool SSL connection (this parameter is optional, default: false)
     * @param $timeout int connection time out (this parameter is optional)
     */
    public function connect($ip, $port, $username, $password, $secure = false, $timeout = 0) {
        $ip = gethostbyname($ip);
        if ($timeout && is_int($timeout)) {
            $this->session = session_open_timeout($secure, $ip, $port, $username, $password, $timeout*1000);
        } else {
            $this->session = session_open($secure, $ip, $port, $username, $password);
        }
        $resp = Debug::checkError($this->session, "_p_session", Debug::FATALERROR, Message::SESSIONERROR);
        if ($resp) {
            $this->checkAxigenVersion();
        }
        return $resp;
    }
    private function checkAxigenVersion() {
        $apiver = show_version();
        $apiver = $apiver['cliLibraryVersion'];
        $apiver = explode(".", $apiver);
        if (count($apiver) > 3) {
            array_pop($apiver);
        }
        $apivwarn = implode(".", $apiver);
        array_pop($apiver);
        $apivdie = implode(".", $apiver);
        $axiver = $this->axigenVersion();
        $axiver = explode(" ", $axiver);
        $axiver = explode(".", $axiver[0]);
        if (count($axiver) > 3) {
            array_pop($axiver);
        }
        $axivwarn = implode(".", $axiver);
        array_pop($axiver);
        $axivdie = implode(".", $axiver);
        if ($axivwarn != $apivwarn) {
            Debug::setError(Message::AXIGENMINORVERSION, Debug::INFOERROR);
        }
        if ($axivdie != $apivdie) {
            die("This version of Axigen CliApi is not compatible with your Axigen server");
        }
    }
    public function getSessionObj() {
        if (!$this) return false;
        return $this->session;
    }
    /**
     * returns an array with PHP files and the Cliclient library version
     * @return array
     */
    public function version() {
        return show_version();
    }
    /**
     * this method returns an array with the enabled domains list filtered by parameter
     * @return array
     * @param $filter string the domain filter (ex: domain*: will list all domains that start with domain) (this parameter is optional)
     */
    public function listDomains($filter = '') {
        if (!$this) return false;
        $domains = array();
        $domainListObj = session_domains_get($this->getSessionObj() , $filter);
        if (!Debug::checkError($domainListObj, "_p_domain_list", Debug::INFOERROR, Message::LISTDOMAINS)) return false;
        $domainListIterObj = domain_iterator_begin($domainListObj);
        if (!Debug::checkError($domainListIterObj, "_p_domain_iterator", Debug::INFOERROR, Message::LISTDOMAINS)) return false;
        while (domain_iterator_has_value($domainListIterObj)) {
            array_push($domains, domain_iterator_value($domainListIterObj));
            domain_iterator_next($domainListIterObj);
        }
        domain_iterator_destroy($domainListIterObj);
        domain_list_destroy($domainListObj);
        return $domains;
    }
    /**
     * this method returns an array with the all domains list filtered by parameter
     * @return array
     * @param $filter string the domain filter (ex: domain*: will list all domains that start with domain) (this parameter is optional)
     */
    public function listAllDomains($filter = '') {
        if (!$this) return false;
        $domains = array();
        $domainListObj = session_all_domains_get($this->getSessionObj() , $filter);
        if (!Debug::checkError($domainListObj, "_p_all_domain_list", Debug::INFOERROR, Message::LISTALLDOMAINS)) return false;
        $domainListIterObj = all_domain_iterator_begin($domainListObj);
        if (!Debug::checkError($domainListIterObj, "_p_all_domain_iterator", Debug::INFOERROR, Message::LISTALLDOMAINS)) return false;
        while (all_domain_iterator_has_value($domainListIterObj)) {
            $dom = all_domain_iterator_value($domainListIterObj);
            $dom = explode(",", $dom);
            $tdom['name'] = $dom[0];
            $tdom['status'] = $dom[1];
            $domains[] = $tdom;
            unset($dom, $tdom);
            all_domain_iterator_next($domainListIterObj);
        }
        all_domain_iterator_destroy($domainListIterObj);
        all_domain_list_destroy($domainListObj);
        return $domains;
    }
    /**
     * this method returns an array with domain activation requests
     * @return array
     */
    public function listDomainActivationRequests() {
        if (!$this) return false;
        $domainActiovationRequests = array();
        $domainActiovationRequestsObj = domain_activation_requests_get($this->getSessionObj());
        if (!Debug::checkError($domainActiovationRequestsObj, "_p_domain_activation_requests", Debug::INFOERROR, Message::LISTDOMAINACTIVATIONREQUEST)) return false;
        $domainActiovationRequestsIterObj = domain_activation_request_iterator_begin($domainActiovationRequestsObj);
        if (!Debug::checkError($domainActiovationRequestsIterObj, "_p_domain_activation_requests_iterator", Debug::INFOERROR, Message::LISTDOMAINACTIVATIONREQUEST)) return false;
        while (domain_activation_requests_iterator_has_value($domainActiovationRequestsIterObj)) {
            unset($request);
            $requestObj = domain_activation_request_iterator_value($domainActiovationRequestsIterObj);
            $request['location'] = domain_activation_request_location_get($requestObj);
            $request['status'] = domain_activation_request_status_get($requestObj);
            array_push($domainActiovationRequests, $request);
            domain_activation_requests_iterator_next($domainActiovationRequestsIterObj);
        }
        domain_activation_requests_iterator_destroy($domainActiovationRequestsIterObj);
        domain_activation_requests_destroy($domainActiovationRequestsObj);
        return $domainActiovationRequests;
    }
    /**
     * this method clears the domain activation request list
     * @return bool
     */
    public function clearDomainActivationRequests() {
        if (!$this) return false;
        $domainActiovationRequestsObj = domain_activation_requests_get($this->getSessionObj());
        if (!Debug::checkError($domainActiovationRequestsObj, "_p_domain_activation_requests", Debug::INFOERROR, Message::CLEARDOMAINACTIVATIONREQUESTS)) return false;
        $resp = clear_domain_activation_requests($domainActiovationRequestsObj, $this->session);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::CLEARDOMAINACTIVATIONREQUESTS);
    }
    /**
     * this method saves the Axigen Configuration on disk
     * @return bool
     */
    public function saveConfig() {
        if (!$this) return false;
        $resp = session_save_config($this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SAVESERVERCONFIG);
    }
    /**
     * this method returns the Axigen version name
     * @return string
     */
    public function axigenVersion() {
        if (!$this) return false;
        return session_version_get($this->getSessionObj());
    }
    /**
     * this method changes the current user password
     * @return bool
     * @param $oldPassword string Admin user old password
     * @param $newPassword string Admin user new password
     */
    public function changePassword($oldPassword, $newPassword) {
        if (!$this) return false;
        if (!is_string($oldPassword) || !is_string($newPassword)) return false;
        $resp = set_admin_password($this->getSessionObj() , $oldPassword, $newPassword);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::CHANGEPASSWORD);
    }
    /**
     * deletes a domain from the server using the domain name
     * @return bool
     * @param $domain string the name of the domain to be deleted
     * @param $dontKeepCopy bool delete the domain from disk (optional, default:false)
     */
    public function deleteDomainName($domain, $dontKeepCopy = false) {
        if (!$this) return false;
        if (!is_string($domain)) return false;
        $resp = session_delete_domain_by_name($this->getSessionObj() , $domain, $dontKeepCopy);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::DELETEDOMAINBYNAME);
    }
    /**
     * deletes a domain from the server using the domain location
     * @return bool
     * @param $domain string the domain location to delete
     * @param $dontKeepCopy bool delete the domain from you disk (optional, default: false)
     */
    public function deleteDomainLocation($domain, $dontKeepCopy = false) {
        if (!$this) return false;
        if (!is_string($domain)) return false;
        $resp = session_delete_domain_by_location($this->getSessionObj() , $domain, $dontKeepCopy);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::DELETEDOMAINBYLOCATION);
    }
    /**
     * disables a domain from the server using the domain name
     * @return bool
     * @param $domain string the name of the domain to disable
     */
    public function disableDomain($domain) {
        if (!$this) return false;
        if (!is_string($domain)) return false;
        $resp = session_disable_domain($this->getSessionObj() , $domain);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::DISABLEDOMAINBYNAME);
    }
    /**
     * enables a domain from the server using the domain name
     * @return bool
     * @param $domain string the name of the domain to enable
     */
    public function enableDomainName($domain) {
        if (!$this) return false;
        if (!is_string($domain)) return false;
        $resp = session_enable_domain_by_name($this->getSessionObj() , $domain);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::ENABLEDOMAINBYNAME);
    }
    /**
     * enables a domain from the server using the domain location
     * @return bool
     * @param $domain string the domain location to enable
     */
    public function enableDomainLocation($domain) {
        if (!$this) return false;
        if (!is_string($domain)) return false;
        $resp = session_enable_domain_by_location($this->getSessionObj() , $domain);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::ENABLEDOMAINBYLOCATION);
    }
    /**
     * this method creates a new domain
     * @return bool/object DomainRegistration
     * @param $domainName string the new domain name
     * @param $domainLocation string location on disk
     * @param $postmasterPassword string postmaster password
     * @param $advanced bool if this is true, an object with the domain registration loaded will be returned, otherwise the command will be executed (default: false)
     */
    public function createDomain($domainName, $domainLocation, $postmasterPassword, $advanced = false) {
        if (!$this) return false;
        if (!is_string($domainName) || !is_string($domainLocation) || !is_string($postmasterPassword)) return false;
        if ($advanced && is_object($this->createdomain[$domainName])) {
            return $this->createdomain[$domainName];
        }
        $newDomain = session_create_domain($this->getSessionObj() , $domainName, $domainLocation, $postmasterPassword);
        if ($advanced) {
            if (!Debug::checkError($newDomain, "_p_domain_registration", Debug::FATALERROR, Message::CREATEDOMAIN)) return false;
            $this->createdomain[$domainName] = new DomainRegistration($newDomain, $this);
            $this->createdomain[$domainName]->domaintype = "domaincreate";
            return $this->createdomain[$domainName];
        }
        if (!Debug::checkError($newDomain, "_p_domain_registration", Debug::INFOERROR, Message::CREATEDOMAIN)) return false;
        $resp = domain_registration_save($newDomain, $this->session);
        domain_registration_destroy($newDomain);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::CREATEDOMAIN);
    }

    /**
     * this method creates a new sub-domain domain
     * @return bool/object DomainRegistration
     * @param $prefix string sub-domain name (prefix for the domain)
     * @param $parentDomain string the parent domain for this sub-domain
     * @param $postmasterPassword string postmaster password
     * @param $advanced bool if this is true, an object with the domain registration loaded will be returned, otherwise the command will be executed (default: false)
     */
    public function createSubDomain($prefix, $parentDomain, $postmasterPassword, $advanced = false) {
        if (!$this) return false;
        if (!is_string($prefix) || !is_string($parentDomain) || !is_string($postmasterPassword) || !is_bool($advanced)) return false;
        if ($advanced && is_object($this->createsubdomain[$prefix . "." . $parentDomain])) {
            return $this->createsubdomain[$prefix . "." . $parentDomain];
        }
        $newSubDomain = session_create_subdomain($this->getSessionObj() , $prefix, $parentDomain, $postmasterPassword);
        if ($advanced) {
            if (!Debug::checkError($newSubDomain, "_p_domain_registration", Debug::FATALERROR, Message::CREATESUBDOMAIN)) return false;
            $this->createsubdomain[$prefix . "." . $parentDomain] = new DomainRegistration($newSubDomain, $this);
            $this->createsubdomain[$prefix . "." . $parentDomain]->domaintype = "subdomaincreate";
            return $this->createsubdomain[$prefix . "." . $parentDomain];
        }
        if (!Debug::checkError($newSubDomain, "_p_domain_registration", Debug::INFOERROR, Message::CREATESUBDOMAIN)) return false;
        $resp = domain_registration_save($newSubDomain, $this->session);
        domain_registration_destroy($newSubDomain);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::CREATESUBDOMAIN);
    }
    /**
     * @return object returns a Domain object with the selected domain loaded
     * @param $domainName string the name of the domain you want to load
     */
    public function updateDomain($domainName) {
        if (!$this) return false;
        if (!is_string($domainName)) return false;
        if ($this->domains != NULL && array_key_exists($domainName, $this->domains) && is_object($this->domains[$domainName])) {
            return $this->domains[$domainName];
        } else {
            $domainObj = session_update_domain($this->getSessionObj() , $domainName);
            if (!Debug::checkError($domainObj, "_p_domain", Debug::FATALERROR, Message::UPDATEDOMAIN)) return false;
            $this->domains[$domainName] = new Domain($domainObj, $this);
            return $this->domains[$domainName];
        }
    }
    /**
     * This function returns an object with the selected domain loaded by name
     * @return object DomainRegistration
     * @param $domainName string the domain name that you want to load
     */
    public function editDomainName($domainName) {
        if (!$this) return false;
        if (!is_string($domainName)) return false;
        if (is_object($this->domainsName[$domainName])) {
            return $this->domainsName[$domainName];
        } else {
            $domainObj = session_edit_domain_by_name($this->getSessionObj() , $domainName);
            if (!Debug::checkError($domainObj, "_p_domain_registration", Debug::FATALERROR, Message::EDITDOMAINBYNAME)) return false;
            $this->domainsName[$domainName] = new DomainRegistration($domainObj, $this);
            return $this->domainsName[$domainName];
        }
    }
    /**
     * This function returns an object with the selected domain loaded by domain location
     * @return object DomainRegistration
     * @param $domainLocation string the domain location that you want to load
     */
    public function editDomainLocation($domainLocation) {
        if (!$this) return false;
        if (!is_string($domainLocation)) return false;
        if (is_object($this->domainsLocation[$domainLocation])) {
            return $this->domainsLocation[$domainLocation];
        } else {
            $domainObj = session_edit_domain_by_location($this->getSessionObj() , $domainLocation);
            if (!Debug::checkError($domainObj, "_p_domain_registration", Debug::FATALERROR, Message::EDITDOMAINBYLOCATION)) return false;
            $this->domainsLocation[$domainLocation] = new DomainRegistration($domainObj, $this);
            return $this->domainsLocation[$domainLocation];
        }
    }
    /**
     * this function returns an object of AACL type
     * @return object Aacl
     */
    public function configAacl() {
        if (!$this) return false;
        if (is_object($this->aacl)) {
            return $this->aacl;
        } else {
            $aaclObj = session_aacl_get($this->getSessionObj());
            if (!Debug::checkError($aaclObj, "_p_aacl", Debug::FATALERROR, Message::AACL)) return false;
            $this->aacl = new Aacl($aaclObj, $this);
            return $this->aacl;
        }
    }
    /**
     * this function returns an object of Server type
     * @return object Server
     */
    public function configServer() {
        if (!$this) return false;
        if (is_object($this->server)) {
            return $this->server;
        } else {
            $serverObj = session_config_server($this->getSessionObj());
            if (!Debug::checkError($serverObj, "_p_server", Debug::FATALERROR, Message::SERVER)) return false;
            $this->server = new Server($serverObj, $this);
            return $this->server;
        }
    }
    /**
     * this function returns an object of Queue type
     * @return object Queue
     */
    public function viewQueue() {
        if (!$this) return false;
        if (is_object($this->queue)) {
            return $this->queue;
        } else {
            $queueObj = server_config_queue($this->getSessionObj());
            if (!Debug::checkError($queueObj, "_p_queue", Debug::FATALERROR, Message::QUEUE)) return false;
            $this->queue = new Queue($queueObj, $this);
            return $this->queue;
        }
    }
    /**
     * this function returns an array with the last error
     * @return array
     */
    public function getLastError() {
        return Debug::getError();
    }
    /**
     * this function returns the last error generated by the server
     * @return string
     */
    public function getServerLastError() {
        return session_lastErr($this->getSessionObj());
    }

     /**
     * this method returns an array with Premium Accounts list filtered by a certain parameter
     * @return array
     * @param $filter string the Premium account filter (ex: account*: will list all the accounts that start with account) (this parameter is optional)
     * @param $domain string the domain filter (optional)
     */
    public function listPremiumAccounts($filter = "", $domain = "") {
        if (!$this) return false;
        is_null($filter) ? $filter = "" : 0;
        is_null($domain) ? $domain = "" : 0;
        $accounts = array();
        if ( $domain != "" ) {
            $domain = "domain {$domain}";
        }   
        $accountsObj = session_premium_accounts_get($this->getSessionObj(), $this->getSessionObj(), $domain, $filter);
        if (!Debug::checkError($accountsObj, "_p_premium_accounts_list", Debug::INFOERROR, Message::LISTPREMIUMACCOUNTS)) return false;
        $accountsIterObj = premium_accounts_iterator_begin($accountsObj);
        if (!Debug::checkError($accountsIterObj, "_p_premium_accounts_iterator", Debug::INFOERROR, Message::LISTPREMIUMACCOUNTS)) return false;

        while(premium_accounts_iterator_has_value($accountsIterObj)) {
            $acc = premium_accounts_iterator_value($accountsIterObj);
            $acc = explode(",", $acc);
            $tacc['name'] = $acc[0];
            $tacc['PersonalOrganizer'] = $acc[1];
            $tacc['Sharing'] = $acc[2];
            $tacc['Outlook'] = $acc[3];
            $tacc['ActiveSync'] = $acc[4];
            $tacc['KasperskyAV'] = $acc[5];
            $tacc['KasperskyAS'] = $acc[6];
            $accounts[] = $tacc;
            unset($acc, $tacc);
            premium_accounts_iterator_next($accountsIterObj);
        }

        premium_accounts_iterator_destroy($accountsIterObj);
        premium_accounts_list_destroy($accountsObj);

        return $accounts;
    }

    /**    
     * this function returns an array with the license info
     * @return array
     */
    public function showLicenseInfo() {
        if(!$this->licenseObj) {
            $lObj = init_license_info($this->getSessionObj());            
            if (!Debug::checkError($lObj, "_p_license_info", Debug::INFOERROR, Message::LOADLICENSE)) return false;

            $this->licenseObj['Version'] = license_info_version_get($lObj);
            $this->licenseObj['MinorVersion'] = license_info_minor_version_get($lObj);
            $this->licenseObj['Description'] = license_info_description_get($lObj);
            $this->licenseObj['RegistrationCode'] = license_info_registration_code_get($lObj);
            $this->licenseObj['User'] = license_info_user_get($lObj);
            $this->licenseObj['Company'] = license_info_company_get($lObj);
            $this->licenseObj['MachineCount'] = license_info_machine_count_get($lObj);
            $this->licenseObj['DomainCount'] = license_info_domain_count_get($lObj);
            $this->licenseObj['MailboxCount'] = license_info_mailbox_count_get($lObj);
            $this->licenseObj['MaillistCount'] = license_info_maillist_count_get($lObj);
            $this->licenseObj['GroupCount'] = license_info_group_count_get($lObj);
            $this->licenseObj['PublicFolderRecipientCount'] = license_info_public_folder_recipient_count_get($lObj);
            $this->licenseObj['ReportDatabaseCount'] = license_info_report_database_count_get($lObj);
            $this->licenseObj['MailboxCountPerDomain'] = license_info_mailbox_count_per_domain_get($lObj);
            $this->licenseObj['MaillistCountPerDomain'] = license_info_maillist_count_per_domain_get($lObj);
            $this->licenseObj['GroupCountPerDomain'] = license_info_group_count_per_domain_get($lObj);
            $this->licenseObj['PublicFolderRecipientCountPerDomain'] = license_info_public_folder_recipient_count_per_domain_get($lObj);
            $this->licenseObj['Distributor'] = license_info_distributor_get($lObj);
            $this->licenseObj['TechSupportProvider'] = license_info_tech_support_provider_get($lObj);
            $this->licenseObj['StartDate'] = license_info_start_date_get($lObj);
            $this->licenseObj['ExpiryDate'] = license_info_expiry_date_get($lObj);
            $this->licenseObj['MaintenanceDate'] = license_info_maintenance_date_get($lObj);
            $this->licenseObj['Addons'] = license_info_addons_get($lObj);
            $this->licenseObj['CommtouchIntegrationExpiryDate'] = license_info_commtouch_integration_expiry_date_get($lObj);
            $this->licenseObj['Type'] = license_info_type_get($lObj);
            $this->licenseObj['PremiumMailboxCount'] = license_info_premium_mailbox_count_get($lObj);
            $this->licenseObj['PremiumMailboxCountPerDomain'] = license_info_premium_mailbox_count_per_domain_get($lObj);
            $this->licenseObj['SharingMailboxCount'] = license_info_sharing_mailbox_count_get($lObj);
            $this->licenseObj['SharingMailboxCountPerDomain'] = license_info_sharing_mailbox_count_per_domain_get($lObj);
            $this->licenseObj['PersonalOrganizerMailboxCount'] = license_info_personal_organizer_mailbox_count_get($lObj);
            $this->licenseObj['PersonalOrganizerMailboxCountPerDomain'] = license_info_personal_organizer_mailbox_count_per_domain_get($lObj);
            $this->licenseObj['OutlookConnectorMailboxCount'] = license_info_outlook_connector_mailbox_count_get($lObj);
            $this->licenseObj['OutlookConnectorMailboxCountPerDomain'] = license_info_outlook_connector_mailbox_count_per_domain_get($lObj);
            $this->licenseObj['ActiveSyncExpiryDate'] = license_info_active_sync_expiry_date_get($lObj);
            $this->licenseObj['ActiveSyncMailboxCount'] = license_info_active_sync_mailbox_count_get($lObj);
            $this->licenseObj['ActiveSyncMailboxCountPerDomain'] = license_info_active_sync_mailbox_count_per_domain_get($lObj);

            license_destroy($lObj);
        }
        return $this->licenseObj;
    }

    /** 
     * this function returns an array with the PremiumAddonsStatistics 
     * @return array
     */
    public function showPremiumAddonsStatistics() {
        $pObj = session_premium_addons_stat_get($this->getSessionObj());
        if (!Debug::checkError($pObj, "_p_premium_addons_stat_list", Debug::INFOERROR, Message::LISTPREMIUMACCOUNTS)) return false;
        $pIterObj = premium_addons_stat_iterator_begin($pObj);
        if (!Debug::checkError($pIterObj, "_p_premium_addons_stat_iterator", Debug::INFOERROR, Message::LISTPREMIUMACCOUNTS)) return false;
        $ret = array();
        while(premium_addons_stat_iterator_has_value($pIterObj)) {
            $prr = premium_addons_stat_iterator_value($pIterObj)."\n";
            $prr = explode(",", $prr);
            $pr['Addon'] = preg_replace(array("/Add-on/", "/ /"), array(""), $prr[0]);
            $pr['Used'] = $prr[1];
            $pr['Total'] = $prr[2];
            $ret[] = $pr; 
            premium_addons_stat_iterator_next($pIterObj);
        }

        premium_addons_stat_iterator_destroy($pIterObj);
        premium_addons_stat_list_destroy($pObj);
        return $ret;
    }
    
    /**
     * purge mails from specified folders of all users from all enabled domains
     * @param $folders string the folders to purge (list is separated by , and names with spaces are between brackets)
     * @param $condition string the purge condition (optional, default: ALL)
     * @return bool
     */
    public function purgeAccountFolders($folders, $condition = null) {
        if (!$this) return false;
        if (!is_string($folders)) return false;
        $resp = session_purge_account_folders($this->getSessionObj() , $folders, $condition);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::PURGEACCOUNTFOLDERS);
    }

    /**
     * purge mails from specified public folders from all enabled domains
     * @param $folders string the public folders to purge (list is separated by , and names with spaces are between brackets)
     * @param $condition string the purge condition (optional, default: ALL)
     * @return bool
     */
    public function purgePublicFolders($folders, $condition = null) {
        if (!$this) return false;
        if (!is_string($folders)) return false;
        $resp = session_purge_public_folders($this->getSessionObj() , $folders, $condition);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::PURGEPUBLICFOLDERS);
    }
}
/** @} */ // end of group
?>
