<?php
/**
 * this is the object containing the Axigen account data for the selected account
 * @note
 * \ingroup updateDomain
 * \defgroup updateAccount updateAccount
 * @{
 */
class Account {
    private $account, $parent;
    private $webmaildata, $filters, $quotas, $limits, $contactinfo, $sendRecvRestrictions, $webmailAdvertising;
    public function __construct($accountObj, $parentObj) {
        $this->account = $accountObj;
        $this->parent = $parentObj;
    }
    public function __destruct() {
        account_destroy($this->getAccountObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getAccountObj() {
        return $this->account;
    }
    /**
     * Returns an array with all the aliases of the selected account
     * @return array
     */
    public function listAliases() {
        $aliases = array();
        $aliasIterObj = account_alias_iterator_begin($this->getAccountObj());
        if (!Debug::checkError($aliasIterObj, "_p_account_alias_iterator", Debug::INFOERROR, Message::LISTACCOUNTALIASES)) return false;
        while (account_alias_iterator_has_value($aliasIterObj)) {
            $aliasObj = account_alias_iterator_value($aliasIterObj);
            array_push($aliases, account_alias_name_get($aliasObj));
            account_alias_iterator_next($aliasIterObj);
        }
        account_alias_iterator_destroy($aliasIterObj);
        return $aliases;
    }
    /**
     * Adds a new alias to the selected account
     * @return bool
     * @param $name string the new alias name
     */
    public function addAlias($name) {
        $resp = account_alias_add($this->getAccountObj() , $name);
        Debug::checkError($resp, 0, Debug::INFOERROR, Message::ADDACCOUNTALIAS);
        return $this->save();
    }
    /**
     * Removes an alias from the selected account
     * @return bool
     * @param $name string the name of the alias that you want to remove from the selected account
     */
    public function removeAlias($name) {
        $resp = account_alias_remove_by_name($this->getAccountObj() , $name);
        Debug::checkError($resp, 0, Debug::INFOERROR, Message::REMOVEACCOUNTALIAS);
        return $this->save();
    }
    /**
     * Returns an array with all the account registry information
     * @return array
     */
    public function registryInformation() {
        $regObj = account_registry_information_get($this->getAccountObj() , $this->getSessionObj());
        if (!Debug::checkError($regObj, "_p_registry_information", Debug::INFOERROR, Message::ACCOUNTREGISTRYINFO)) return false;
        $reg['creationDate'] = registry_information_creation_date_get($regObj);
        $reg['modificationDate'] = registry_information_modification_date_get($regObj);
        $reg['pop3LastLoginDate'] = registry_information_pop3_last_login_date_get($regObj);
        $reg['pop3LastLoginIp'] = registry_information_pop3_last_login_ip_get($regObj);
        $reg['imapLastLoginDate'] = registry_information_imap_last_login_date_get($regObj);
        $reg['imapLastLoginIp'] = registry_information_imap_last_login_ip_get($regObj);
        $reg['webmailLastLoginDate'] = registry_information_webmail_last_login_date_get($regObj);
        $reg['webmailLastLoginIp'] = registry_information_webmail_last_login_ip_get($regObj);
        $reg['mboxSize'] = (int)registry_information_mbox_size_get($regObj);
        $reg['mboxMessageCount'] = (int)registry_information_mbox_message_count_get($regObj);
        $reg['mboxFolderCount'] = (int)registry_information_mbox_folder_count_get($regObj);
        registry_information_destroy($regObj);
        return $reg;
    }
    /**
     * Uploads a Webmail Filter to the account
     * @return bool
     * @param $filterData string the filter data that you want to upload
     */
    public function uploadWmFilter($filterData) {
        if (!$this) return false;
        $resp = account_upload_wmfilter($this->getAccountObj() , $this->getSessionObj() , $filterData);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::ACCOUNTUPLOADWMFILTER);
    }
    /**
     * Sets the account settings' inheritance from the domain's defaults
     * @return bool
     */
    public function inheritSettingsFromDomainDefaults() {
        $resp = account_inherit_settings_from_domain_defaults($this->getAccountObj() , $this->getSessionObj());
        Debug::checkError($resp, 0, Debug::INFOERROR, Message::ACCOUNTINHERITDOMAIN);
        return $this->save();
    }
    /**
     * Sets the account settings' inheritance from the account class
     * @return bool
     * @param $accountClass string the account class name that you want to set for the selected user
     */
    public function inheritSettingsFromAccountClass($accountClass) {
        $resp = account_inherit_settings_from_account_class($this->getAccountObj() , $this->getSessionObj() , $accountClass);
        Debug::checkError($resp, 0, Debug::INFOERROR, Message::ACCOUNTINHERITACCOUNTCLASS);
        return $this->save();
    }
    /**
     * Returns an object pertaining to WebmailData for the selected account
     * @return object WebmailData
     */
    public function configWebmailData() {
        if (!$this) return false;
        if (!is_object($this->webmaildata)) {
            $webmailDataObj = account_webmaildata_get($this->getAccountObj() , $this->getSessionObj());
            if (!Debug::checkError($webmailDataObj, "_p_webmaildata", Debug::FATALERROR, Message::LOADACCOUNTWEBMAILDATA)) return false;
            $this->webmaildata = new WebmailData($webmailDataObj, $this);
        }
        return $this->webmaildata;
    }
    /**
     * Returns an object pertaining to WebmailAdvertising for the selected account
     * @return object WebmailAdvertising
     */
    public function configWebmailAdvertising() {
        if (!$this) return false;
        if (!is_object($this->webmailAdvertising)) {
            $webmailAdvertisingObj = account_webmailadvertising_get($this->getAccountObj() , $this->getSessionObj());
            if (!Debug::checkError($webmailAdvertisingObj, "_p_webmailadvertising", Debug::FATALERROR, Message::LOADACCOUNTWEBMAILADVERTISING)) return false;
            $this->webmailAdvertising = new WebmailAdvertising($webmailAdvertisingObj, $this);
        }
        return $this->webmailAdvertising;
    }
    /**
     * Returns an object of SendRecvRestrictions type for the selected account
     * @return object SendRecvRestrictions
     */
    public function configSendRecvRestrictions() {
        if (!$this) return false;
        if (!is_object($this->sendRecvRestrictions)) {
            $sendRecvObj = account_send_recv_restrictions($this->getAccountObj() , $this->getSessionObj());
            if (!Debug::checkError($sendRecvObj, "_p_send_recv_restrictions", Debug::FATALERROR, Message::ACCOUNTLOADSENDRECV)) return false;
            $this->sendRecvRestrictions = new SendRecvRestrictions($sendRecvObj, $this);
        }
        return $this->sendRecvRestrictions;
    }
    /**
     * Returns an object pertaining to Filters for the selected account
     * @return object Filters
     */
    public function configFilters() {
        if (!$this) return false;
        if (!is_object($this->filters)) {
            $filterObj = account_filters_get($this->getAccountObj() , $this->getSessionObj());
            if (!Debug::checkError($filterObj, "_p_filters", Debug::FATALERROR, Message::LOADACCOUNTFILTERS)) return false;
            $this->filters = new Filters($filterObj, $this);
        }
        return $this->filters;
    }
    /**
     * Returns an object pertaining to Contact Info for the selected account
     * @return object ContactInfo
     */
    public function configContactInfo() {
        if (!$this) return false;
        if (!is_object($this->contactinfo)) {
            $contactInfoObj = account_contact_info_get($this->getAccountObj() , $this->getSessionObj());
            if (!Debug::checkError($contactInfoObj, "_p_contact_info", Debug::FATALERROR, Message::LOADACCOUNTCONTACTINFO)) return false;
            $this->contactinfo = new ContactInfo($contactInfoObj, $this);
        }
        return $this->contactinfo;
    }
    /**
     *  Returns an object pertaining to Quotas for the selected account
     * @return object Quotas
     */
    public function configQuotas() {
        if (!$this) return false;
        if (!is_object($this->quotas)) {
            $quotasObj = account_quotas_get($this->getAccountObj() , $this->getSessionObj());
            if (!Debug::checkError($quotasObj, "_p_quotas", Debug::FATALERROR, Message::LOADACCOUNTQUOTAS)) return false;
            $this->quotas = new Quotas($quotasObj, $this);
        }
        return $this->quotas;
    }
    /**
     * Returns an object pertaining to Limits for the selected account
     * @return object Limits
     */
    public function configLimits() {
        if (!$this) return false;
        if (!is_object($this->limits)) {
            $limitsObj = account_limits_get($this->getAccountObj() , $this->getSessionObj());
            if (!Debug::checkError($limitsObj, "_p_limits", Debug::FATALERROR, Message::LOADACCOUNTLIMITS)) return false;
            $this->limits = new Limits($limitsObj, $this);
        }
        return $this->limits;
    }

    /**
     * this method must be called if one of the members has been changed
     * @return bool
     */
    public function save() {
        if (!$this) return false;
        $resp = account_save($this->getAccountObj() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SAVEACCOUNTDATA);
    }

    /**
     * resets the ldap associations
     * @return bool
     */
    public function resetLdapAssociation() {
        if (!$this) return false;
        $resp = account_reset_ldapassociation($this->getAccountObj() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::ACCOUNTRESETLDAPASSOCIATION);
    }

    /**
     * Set members.
     * <table>
<tr><th>member</th><th>description</th>
<tr><td>name</td><td>account name</td>
<tr><td>password</td><td>account password</td>
<tr><td>customerReference</td><td>the customer reference for use with external billing like systems</td>
<tr><td>publishContactInfo</td><td>the enabled/disabled publish contact info</td>
<tr><td>accountType</td><td>the account type</td>
<tr><td>senderNotInAddressBookAction</td><td>this is the action selected by the user in Webmail to be executed if the email sender is not in his/her address book</td>
</table>
     */
    public function __set($varName, $varValue) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "name":
                $resp = account_name_set($this->getAccountObj() , $varValue);
            break;
            case "password":
                $resp = account_password_set($this->getAccountObj() , $varValue);
            break;
            case "customerreference":
                $resp = account_customer_reference_set($this->getAccountObj() , $varValue);
            break;
            case "publishcontactinfo":
                $resp = account_publish_contact_info_set($this->getAccountObj() , $varValue);
            break;
            case "accounttype":
                $resp = account_account_type_set($this->getAccountObj() , $varValue);
            break;
            case "sendernotinaddressbookaction":
                return account_sender_not_in_address_book_action_set($this->getAccountObj(), $varValue);
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::SETACCOUNTVARERROR);
                return;
        }
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETACCOUNTVARERROR);
    }
    /**
     * Get members.
     * <table>
<tr><th>member</th><th>description</th>
<tr><td>name</td><td>account name</td>
<tr><td>password</td><td>account password</td>
<tr><td>customerReference</td><td>the customer reference for use with external billing like systems</td>
<tr><td>publishContactInfo</td><td>the enabled/disabled publish contact info</td>
<tr><td>accountType</td><td>the account type</td>
<tr><td>senderNotInAddressBookAction</td><td>this is the action selected by the user in Webmail to be executed if the email sender is not in his/her address book</td>
</table>
     */
    public function __get($varName) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "name":
                return account_name_get($this->getAccountObj());
            break;
            case "accountclassname":
                return account_account_class_name_get($this->getAccountObj());
            break;
            case "sendernotinaddressbookaction":
                return account_sender_not_in_address_book_action_get($this->getAccountObj());
            break;
            case "customerreference":
                return account_customer_reference_get($this->getAccountObj());
            break;
            case "publishcontactinfo":
                return account_publish_contact_info_get($this->getAccountObj());
            break;
            case "accounttype":
                return account_account_type_get($this->getAccountObj());
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::GETACCOUNTVARERROR);
        }
    }
    /*    
     * Purge mails from specified folders on selected user
     * @param $folders string the folders to purge (list is separated by , and names with spaces are between brackets)
     * @param $conditon string the purge condition (optional, default: ALL)
     * @return bool
     */
    public function purgeAccountFolders($folders, $condition = null) {
        if (!$this) return false;
        if (!is_string($folders)) return false;
        $resp = account_purge_account_folders($this->getAccountObj(), $this->getSessionObj() , $folders, $condition);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::PURGEACCOUNTFOLDERS);
    }

}
/** @} */ // end of group
?>
