<?php
/**
 * This is the object containing the Axigen domain data for the selected domain
* \section config_filters_note Note of configFilters
* Please note that (Sieve) filters are either managed from the WebAdmin or from the CLIAPI.
* If at least one WebAdmin filter is defined, the configFilters()->listActiveFilters() call will fail.
* This is caused by the Axigen CLI service refusing to allow updates on a filter that is managed by the WebAdmin interface.
* If no WebAdmin filters have been defined, you can use the configFilters API to define domain level filters.
*
* \subsection samples_sieve_1 Configuring a sieve filter via the CLIAPI
* The first thing you need to do is to save the Sieve filter as a file in Axigen's filters directory.
* In the default configuration, that is /var/opt/axigen/filters.
* A filter might look like this:
* \verbatim
[axi@axi]# cat /var/opt/axigen/filters/ca_filter.script
require ["fileinto", "envelope"];
if anyof (
    header :contains  ["Subject"] ["trash"]
) {
    fileinto "Trash";
    stop;
}
* \endverbatim
* Once the sieve filter file has been saved, you can activate it using the CLIAPI:
* \code
<?php
    // with "domain" as the domain object
    $cf = domain->configFilters();
    $cf->addScriptFilter("caFilter", "ca_filter.script");
    $cf->addActiveFilter("100", "caFilter", "script");
    $cf->save();
?>
* \endcode
 * \ingroup cliobject
 * \defgroup updateDomain updateDomain
 * @{
 */
class Domain {
    private $domain, $parent, $accounts, $groups, $accountclasses, $folderrcpts, $list, $permissions, $services, $accountclassesObj;
    private $filters, $accountDefaultFilters, $accountDefaultLimits, $accountDefaultQuotas, $publicFolder, $migrationdata, $adminlimits;
    private $accountDefaultSendRecvRestrictions, $accountDefaultWebmailAdvertising;
    public function __construct($domainObj, $parentObj) {
        $this->domain = $domainObj;
        $this->parent = $parentObj;
    }
    public function __destruct() {
        domain_destroy($this->getDomainObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getDomainObj() {
        return $this->domain;
    }
    public function getDomainServicesObj() {
        if (!is_resource($this->services)) {
            $this->services = domain_services_get($this->getDomainObj());
            if (!Debug::checkError($this->services, "_p_services", Debug::FATALERROR, Message::GETDOMAINSSERVICES)) return false;
        }
        return $this->services;
    }
    public function getAccountClasses($die = Debug::INFOERROR, $filter = null) {
        if (!is_resource($this->accountclassesObj) || !is_null($filter)) {
            $this->accountclassesObj = account_classes_get($this->getDomainObj() , $this->getSessionObj() , $filter);
            if (!Debug::checkError($this->accountclassesObj, "_p_account_classes", $die, Message::LOADACCOUNTCLASSES)) return false;
        }
        return $this->accountclassesObj;
    }
    /**
     * this method returns an array with the accounts list filtered by a certain parameter
     * @return array
     * @param $filter string the account filter (ex: account*: will list all the accounts that start with account) (this parameter is optional)
     */
    public function listAccounts($filter = "") {
        if (!$this) return false;
        $accounts = array();
        $accountsObj = domain_accounts_get($this->getDomainObj() , $this->getSessionObj() , $filter);
        if (!Debug::checkError($accountsObj, "_p_account_list", Debug::INFOERROR, Message::LISTACCOUNTS)) return false;
        $accountsIterObj = account_iterator_begin($accountsObj);
        if (!Debug::checkError($accountsIterObj, "_p_account_iterator", Debug::INFOERROR, Message::LISTACCOUNTS)) return false;
        while (account_iterator_has_value($accountsIterObj)) {
            array_push($accounts, account_iterator_value($accountsIterObj));
            account_iterator_next($accountsIterObj);
        }
        account_iterator_destroy($accountsIterObj);
        account_list_destroy($accountsObj);
        return $accounts;
    }
    /**
     * this method returns an array with all the domain aliases
     * @return array
     */
    public function listAliases() {
        if (!$this) return false;
        $aliases = array();
        $aliasesIterObj = domain_alias_iterator_begin($this->getDomainObj());
        if (!Debug::checkError($aliasesIterObj, "_p_domain_alias_iterator", Debug::INFOERROR, Message::LISTALIASES)) return false;
        while (domain_alias_iterator_has_value($aliasesIterObj)) {
            array_push($aliases, domain_alias_value($aliasesIterObj));
            domain_alias_iterator_next($aliasesIterObj);
        }
        domain_alias_iterator_destroy($aliasesIterObj);
        return $aliases;
    }
    /**
     * this method returns an array with the groups list filtered by a certain parameter
     * @return array
     * @param $filter string the group filter (ex: group*: will list all the groups that start with group) (this parameter is optional)
     */
    public function listGroups($filter = "") {
        if (!$this) return false;
        $groups = array();
        $groupsObj = domain_groups_get($this->getDomainObj() , $this->getSessionObj() , $filter);
        if (!Debug::checkError($groupsObj, "_p_group_list", Debug::INFOERROR, Message::LISTGROUPS)) return false;
        $groupsIterObj = group_iterator_begin($groupsObj);
        if (!Debug::checkError($groupsIterObj, "_p_group_iterator", Debug::INFOERROR, Message::LISTGROUPS)) return false;
        while (group_iterator_has_value($groupsIterObj)) {
            array_push($groups, group_iterator_value($groupsIterObj));
            group_iterator_next($groupsIterObj);
        }
        group_iterator_destroy($groupsIterObj);
        group_list_destroy($groupsObj);
        return $groups;
    }
    /**
     * this method returns an array with a folderRcpts list filtered by a certain parameter
     * @return array
     * @param $filter string the folderRcpt filter (ex: folderRcpt*: will list all the folderRcpts that start with folderRcpt) (this parameter is optional)
     */
    public function listFolderRcpts($filter = "") {
        if (!$this) return false;
        $foderRcpts = array();
        $foderRcptsObj = domain_folder_rcpts_get($this->getDomainObj() , $this->getSessionObj() , $filter);
        if (!Debug::checkError($foderRcptsObj, "_p_folder_rcpt_list", Debug::INFOERROR, Message::LISTFOLDERRCPT)) return false;
        $foderRcptsIterObj = folder_rcpt_iterator_begin($foderRcptsObj);
        if (!Debug::checkError($foderRcptsIterObj, "_p_folder_rcpt_iterator", Debug::INFOERROR, Message::LISTFOLDERRCPT)) return false;
        while (folder_rcpt_iterator_has_value($foderRcptsIterObj)) {
            array_push($foderRcpts, folder_rcpt_iterator_value($foderRcptsIterObj));
            folder_rcpt_iterator_next($foderRcptsIterObj);
        }
        folder_rcpt_iterator_destroy($foderRcptsIterObj);
        folder_rcpt_list_destroy($foderRcptsObj);
        return $foderRcpts;
    }
    /**
     * this method returns an array with a groups list filtered by a certain parameter
     * @return array
     * @param $filter string the Lists filter (ex: list*: will list all the Lists that start with list) (this parameter is optional)
     */
    public function listLists($filter = "") {
        if (!$this) return false;
        $lists = array();
        $listsRcptsObj = domain_maillists_get($this->getDomainObj() , $this->getSessionObj() , $filter);
        if (!Debug::checkError($listsRcptsObj, "_p_maillist_list", Debug::INFOERROR, Message::LISTLISTS)) return false;
        $listsRcptsIterObj = maillist_iterator_begin($listsRcptsObj);
        if (!Debug::checkError($listsRcptsIterObj, "_p_maillist_iterator", Debug::INFOERROR, Message::LISTLISTS)) return false;
        while (maillist_iterator_has_value($listsRcptsIterObj)) {
            array_push($lists, maillist_iterator_value($listsRcptsIterObj));
            maillist_iterator_next($listsRcptsIterObj);
        }
        maillist_iterator_destroy($listsRcptsIterObj);
        maillist_list_destroy($listsRcptsObj);
        return $lists;
    }
    /**
     * this method returns an array with an Account Classes list filtered by a certain parameter
     * @return array
     * @param $filter string the AccountClasses filter (ex: accountclass*: will list all the AccountClasses that start with accountclass) (this parameter is optional)
     */
    public function listAccountClasses($filter = "") {
        if (!$this) return false;
        $accountClasses = array();
        $accountClassesObj = $this->getAccountClasses(Debug::INFOERROR, $filter);
        if (!$accountClassesObj) return false;
        $accountClassesRcptsIterObj = account_class_iterator_begin($accountClassesObj);
        if (!Debug::checkError($accountClassesRcptsIterObj, "_p_account_class_iterator", Debug::INFOERROR, Message::LISTACCOUNTCLASS)) return false;
        while (account_class_iterator_has_value($accountClassesRcptsIterObj)) {
            $accObj = account_class_iterator_value($accountClassesRcptsIterObj);
            array_push($accountClasses, account_class_name_get($accObj));
            account_class_iterator_next($accountClassesRcptsIterObj);
        }
        account_class_iterator_destroy($accountClassesRcptsIterObj);
        return $accountClasses;
    }
    /**
     * this method returns an array with domain Registry Information
     * @return array
     */
    public function registryInformation() {
        if (!$this) return false;
        $registryInformation = array();
        $regObj = domain_registration_get($this->getDomainObj() , $this->getSessionObj());
        if (!Debug::checkError($regObj, "_p_domain_registration", Debug::INFOERROR, Message::DOMAINREGISTRYINFORMATION)) return false;
        $registryInformation['creationDate'] = domain_registration_creation_date_get($regObj);
        $registryInformation['modificationDate'] = domain_registration_modification_date_get($regObj);
        $registryInformation['accessDate'] = domain_registration_access_date_get($regObj);
        domain_registration_destroy($regObj);
        return $registryInformation;
    }
    /**
     * this method returns an array with domain Storage Information
     * @return array
     */
    public function storageInformation() {
        if (!$this) return false;
        $storageInformation = array();
        $storageInfoObj = domain_storages_get($this->getDomainObj() , $this->getSessionObj());
        if (!Debug::checkError($storageInfoObj, "_p_domain_storages", Debug::INFOERROR, Message::LISTSTORAGES)) return false;
        $storageInfoIterObj = domain_storage_iterator_begin($storageInfoObj);
        if (!Debug::checkError($storageInfoIterObj, "_p_domain_storage_iterator", Debug::INFOERROR, Message::LISTSTORAGES)) return false;
        while (domain_storage_iterator_has_value($storageInfoIterObj)) {
            $tmpStorage = array();
            $storageObj = domain_storage_iterator_value($storageInfoIterObj);
            $tmpStorage['location'] = domain_storage_location_get($storageObj);
            $tmpStorage['usid'] = domain_storage_usid_get($storageObj);
            $tmpStorage['maxFileSize'] = domain_storage_max_file_size_get($storageObj);
            $tmpStorage['maxFileCount'] = domain_storage_max_file_count_get($storageObj);
            $tmpStorage['total'] = domain_storage_total_get($storageObj);
            $tmpStorage['used'] = domain_storage_used_get($storageObj);
            array_push($storageInformation, $tmpStorage);
            domain_storage_iterator_next($storageInfoIterObj);
        }
        domain_storage_iterator_destroy($storageInfoIterObj);
        domain_storages_destroy($storageInfoObj);
        return $storageInformation;
    }
    /**
     * this method adds an account to the domain
     * @return bool
     * @param $name string this is the name for the new account
     * @param $pass string this is the password for the new account
     */
    public function addAccount($name, $pass) {
        if (!$this) return false;
        if (!is_string($name) || !is_string($pass)) return false;
        $accObj = domain_add_account($this->getDomainObj() , $this->getSessionObj() , $name, $pass);
        if (!Debug::checkError($accObj, "_p_account", Debug::INFOERROR, Message::ADDACCOUNT)) return false;
        $resp = account_save($accObj, $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::ADDACCOUNT);
    }
    /**
     * this method removes an account from the domain
     * @return bool
     * @param $name string this is the account name that will be removed from the domain
     */
    public function removeAccount($name) {
        if (!$this) return false;
        if (!is_string($name)) return false;
        $resp = domain_remove_account($this->getDomainObj() , $this->getSessionObj() , $name);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::REMOVEACCOUNT);
    }
    /**
     * this method returns an object with the selected account loaded
     * @return Account
     * @param $name string this is the account name that will be loaded
     */
    public function updateAccount($name) {
        if (!$this) return false;
        if (!is_string($name)) return false;
        if (is_object($this->accounts[$name])) {
            return $this->accounts[$name];
        } else {
            $accountObj = domain_update_account($this->getDomainObj() , $this->getSessionObj() , $name);
            if (!Debug::checkError($accountObj, "_p_account", Debug::FATALERROR, Message::UPDATEACCOUNT)) return false;
            $this->accounts[$name] = new Account($accountObj, $this);
            return $this->accounts[$name];
        }
    }
    /**
     * this method adds a new Group to the domain
     * @return bool
     * @param $name string this is the group name that will be added to the domain
     */
    public function addGroup($name) {
        if (!$this) return false;
        if (!is_string($name)) return false;
        $groupObj = domain_add_group($this->getDomainObj() , $this->getSessionObj() , $name);
        if (!Debug::checkError($groupObj, "_p_group", Debug::INFOERROR, Message::ADDGROUP)) return false;
        $resp = group_save($groupObj, $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::ADDGROUP);
    }
    /**
     * this method removes a group from the domain
     * @return bool
     * @param $name string this is the group name that will be removed from the domain
     */
    public function removeGroup($name) {
        if (!$this) return false;
        if (!is_string($name)) return false;
        $resp = domain_remove_group($this->getDomainObj() , $this->getSessionObj() , $name);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::REMOVEGROUP);
    }
    /**
     * this method returns an object with the selected group loaded
     * @return Group
     * @param $name string this is the group name that will be loaded
     */
    public function updateGroup($name) {
        if (!$this) return false;
        if (!is_string($name)) return false;
        if (is_object($this->groups[$name])) {
            return $this->groups[$name];
        } else {
            $groupObj = domain_update_group($this->getDomainObj() , $this->getSessionObj() , $name);
            if (!Debug::checkError($groupObj, "_p_group", Debug::FATALERROR, Message::UPDATEGROUP)) return false;
            $this->groups[$name] = new Group($groupObj, $this);
            return $this->groups[$name];
        }
    }
    /**
     * this method adds a new FolderRcpt to the domain
     * @return bool
     * @param $name string this is the FolderRcpt name that will be added to the domain
     */
    public function addFolderRcpt($name) {
        if (!$this) return false;
        if (!is_string($name)) return false;
        $folderRcptObj = domain_add_folder_rcpt($this->getDomainObj() , $this->getSessionObj() , $name);
        if (!Debug::checkError($folderRcptObj, "_p_folder_rcpt", Debug::INFOERROR, Message::ADDFOLDERRCPT)) return false;
        $resp = folder_rcpt_save($folderRcptObj, $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::ADDFOLDERRCPT);
    }
    /**
     * this method removes a FolderRcpt from the domain
     * @return bool
     * @param $name string this is the folderRcpt name that will be removed from the domain
     */
    public function removeFolderRcpt($name) {
        if (!$this) return false;
        if (!is_string($name)) return false;
        $resp = domain_remove_folder_rcpt($this->getDomainObj() , $this->getSessionObj() , $name);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::REMOVEFOLDERRCPT);
    }
    /**
     * this method returns an object with the selected Folder Rcpt loaded
     * @return FolderRcpt
     * @param $name string this is the Folder Rcpt name that will be loaded
     */
    public function updateFolderRcpt($name) {
        if (!$this) return false;
        if (!is_string($name)) return false;
        if (is_object($this->folderrcpts[$name])) {
            return $this->folderrcpts[$name];
        } else {
            $folderrcptObj = domain_update_folder_rcpt($this->getDomainObj() , $this->getSessionObj() , $name);
            if (!Debug::checkError($folderrcptObj, "_p_folder_rcpt", Debug::FATALERROR, Message::UPDATEFOLDERRCPT)) return false;
            $this->folderrcpts[$name] = new FolderRcpt($folderrcptObj, $this);
            return $this->folderrcpts[$name];
        }
    }
    /**
     * this method adds a new List to the domain
     * @return bool
     * @param $name string this is the list name that will be added to the domain
     * @param $pass string this is the list password
     * @param $adminEmail string this is the list admin email address
     */
    public function addList($name, $pass, $adminEmail) {
        if (!$this) return false;
        if (!is_string($name) || !is_string($pass) || !is_string($adminEmail)) return false;
        $listObj = domain_add_maillist($this->getDomainObj() , $this->getSessionObj() , $name, $pass, $adminEmail);
        if (!Debug::checkError($listObj, "_p_maillist", Debug::INFOERROR, Message::ADDLIST)) return false;
        $resp = maillist_save($listObj, $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::ADDLIST);
    }
    /**
     * this method removes a List from the domain
     * @return bool
     * @param $name string this is the list name that will be removed from the domain
     */
    public function removeList($name) {
        if (!$this) return false;
        if (!is_string($name)) return false;
        $resp = domain_remove_maillist($this->getDomainObj() , $this->getSessionObj() , $name);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::REMOVELIST);
    }
    /**
     * this method returns an object with the selected MailList loaded
     * @return MailList
     * @param $name string this is the list name that will be loaded
     */
    public function updateList($name) {
        if (!$this) return false;
        if (!is_string($name)) return false;
        if (is_object($this->list[$name])) {
            return $this->list[$name];
        } else {
            $listObj = domain_update_maillist($this->getDomainObj() , $this->getSessionObj() , $name);
            if (!Debug::checkError($listObj, "_p_maillist", Debug::FATALERROR, Message::UPDATELIST)) return false;
            $this->list[$name] = new MailList($listObj, $this);
            return $this->list[$name];
        }
    }
    /**
     * this method adds a new Account Class to the domain
     * @return bool
     * @param $name string this is the Account class name that will be added to the domain
     */
    public function addAccountClass($name) {
        if (!$this) return false;
        if (!is_string($name)) return false;
        $accountClassesObj = $this->getAccountClasses();
        if (!$accountClassesObj) return false;
        $accountClassObj = account_classes_add($accountClassesObj, $this->getSessionObj() , $name);
        if (!Debug::checkError($accountClassObj, "_p_account_class", Debug::INFOERROR, Message::ADDACCOUNTCLASS)) return false;
        $resp = account_class_save($accountClassObj, $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::ADDACCOUNTCLASS);
    }
    /**
     * this method removes an Account Class from the domain
     * @return bool
     * @param $name string this is the Account Class name that will be removed from the domain
     */
    public function removeAccountClass($name) {
        if (!$this) return false;
        if (!is_string($name)) return false;
        $accountClassesObj = $this->getAccountClasses();
        if (!$accountClassesObj) return false;
        $resp = account_classes_remove_by_name($accountClassesObj, $this->getSessionObj() , $name);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::REMOVEACCOUNTCLASS);
    }
    /**
     * this method returns an object with the selected Account Class loaded
     * @return object AccountClass
     * @param $name string this is the Account Class name that will be loaded
     */
    public function updateAccountClass($name) {
        if (!$this) return false;
        if (!is_string($name)) return false;
        if (is_object($this->accountclasses[$name])) {
            return $this->accountclasses[$name];
        } else {
            $accountClassesObj = $this->getAccountClasses(Debug::FATALERROR);
            if (!$accountClassesObj) return false;
            $accountClassObj = account_classes_account_class_get_by_name($accountClassesObj, $name);
            if (!Debug::checkError($accountClassObj, "_p_account_class", Debug::FATALERROR, Message::UPDATEACCOUNTCLASS)) return false;
            $this->accountclasses[$name] = new AccountClass($accountClassObj, $this);
            return $this->accountclasses[$name];
        }
    }
    /**
     * this method adds a new Alias to the domain
     * @return bool
     * @param $name string this is the Alias name that will be added to the domain
     */
    public function addAlias($name) {
        if (!$this) return false;
        if (!is_string($name)) return false;
        $resp = domain_alias_add($this->getDomainObj() , $name);
        Debug::checkError($resp, 0, Debug::INFOERROR, Message::ADDALIAS);
        return $this->save();
    }
    /**
     * this method removes an Alias from the domain
     * @return bool
     * @param $name string this is the Alias name that will be removed from the domain
     */
    public function removeAlias($name) {
        if (!$this) return false;
        if (!is_string($name)) return false;
        $resp = domain_alias_remove_by_name($this->getDomainObj() , $name);
        Debug::checkError($resp, 0, Debug::INFOERROR, Message::REMOVEALIAS);
        return $this->save();
    }
    /**
     * This function returns an object of Filters type for the selected domain
     * @return object Filters
     * @note these filters apply at domain level
     */
    public function configFilters() {
        if (!$this) return false;
        if (!is_object($this->filters)) {
            $filterObj = domain_filters_get($this->getDomainObj() , $this->getSessionObj());
            if (!Debug::checkError($filterObj, "_p_filters", Debug::FATALERROR, Message::LOADDOMAINFILTERS)) return false;
            $this->filters = new Filters($filterObj, $this);
        }
        return $this->filters;
    }
    /**
     * This function returns an object of AdminLimits type for the selected domain
     * @return object AdminLimits
     */
    public function configAdminLimits() {
        if (!$this) return false;
        if (!is_object($this->adminlimits)) {
            $adminlimitsObj = admin_limits_get($this->getDomainObj() , $this->getSessionObj());
            if (!Debug::checkError($adminlimitsObj, "_p_admin_limits", Debug::FATALERROR, Message::LOADDOMAINADMINLIMITS)) return false;
            $this->adminlimits = new AdminLimits($adminlimitsObj, $this);
        }
        return $this->adminlimits;
    }
    /**
     * these filters are applied to the accounts that inherit filters from the domain Account Defaults Filters
     * @note these filters are designed for those accounts that inherit filters from the domain Account Defaults Filters
     * @return object Filters
     */
    public function configAccountDefaultFilters() {
        if (!$this) return false;
        if (!is_object($this->accountDefaultFilters)) {
            $accountDFilterObj = account_default_filters_get($this->getDomainObj() , $this->getSessionObj());
            if (!Debug::checkError($accountDFilterObj, "_p_filters", Debug::FATALERROR, Message::LOADACCOUNTDEFAULTFILTERS)) return false;
            $this->accountDefaultFilters = new Filters($accountDFilterObj, $this);
        }
        return $this->accountDefaultFilters;
    }
    /**
     * these limits are applied to the accounts that inherit limits from the domain Account Defaults Limits
     * @note these limits are designed for those accounts that inherit limits from the domain Account Defaults Limits
     * @return object Limits
     */
    public function configAccountDefaultLimits() {
        if (!$this) return false;
        if (!is_object($this->accountDefaultLimits)) {
            $accountDLimitsObj = account_default_limits_get($this->getDomainObj() , $this->getSessionObj());
            if (!Debug::checkError($accountDLimitsObj, "_p_limits", Debug::FATALERROR, Message::LOADACCOUNTDEFAULTLIMITS)) return false;
            $this->accountDefaultLimits = new Limits($accountDLimitsObj, $this);
        }
        return $this->accountDefaultLimits;
    }
    /**
     * these quotas are applied to the accounts that inherit quotas from the domain Account Defaults Quotas
     * @note these quotas are designed for those accounts that inherit quotas from the domain Account Defaults Quotas
     * @return object Quotas
     */
    public function configAccountDefaultQuotas() {
        if (!$this) return false;
        if (!is_object($this->accountDefaultQuotas)) {
            $accountDQuotasObj = account_default_quotas_get($this->getDomainObj() , $this->getSessionObj());
            if (!Debug::checkError($accountDQuotasObj, "_p_quotas", Debug::FATALERROR, Message::LOADACCOUNTDEFAULTQUOTAS)) return false;
            $this->accountDefaultQuotas = new Quotas($accountDQuotasObj, $this);
        }
        return $this->accountDefaultQuotas;
    }
    /**
     * returns the account default Webmail advertising object
     * @return object WebmailAdvertising
     */
    public function configAccountDefaultWebmailAdvertising() {
        if (!$this) return false;
        if (!is_object($this->accountDefaultWebmailAdvertising)) {
            $accountDWebmailAdvertisingObj = account_default_webmailadvertising_get($this->getDomainObj() , $this->getSessionObj());
            if (!Debug::checkError($accountDWebmailAdvertisingObj, "_p_webmailadvertising", Debug::FATALERROR, Message::LOADACCOUNTDEFAULTWEBMAILADVERTISING)) return false;
            $this->accountDefaultWebmailAdvertising = new WebmailAdvertising($accountDWebmailAdvertisingObj, $this);
        }
        return $this->accountDefaultWebmailAdvertising;
    }
    /**
     * This function returns an object of PublicFolder type for the selected domain
     * @return object PublicFolder
     */
    public function configPublicFolder() {
        if (!$this) return false;
        if (!is_object($this->publicFolder)) {
            $publicFolderObj = domain_public_folders_get($this->getDomainObj() , $this->getSessionObj());
            if (!Debug::checkError($publicFolderObj, "_p_public_folders", Debug::FATALERROR, Message::LOADPUBLICFOLDER)) return false;
            $this->publicFolder = new PublicFolder($publicFolderObj, $this);
        }
        return $this->publicFolder;
    }
    /**
     * This function returns an object of SendRecvRestrictions type for the selected domain
     * @return object SendRecvRestrictions
     */
    public function configAccountDefaultSendRecvRestrictions() {
        if (!$this) return false;
        if (!is_object($this->accountDefaultSendRecvRestrictions)) {
            $sendRecvObj = domain_account_send_recv_restrictions($this->getDomainObj() , $this->getSessionObj());
            if (!Debug::checkError($sendRecvObj, "_p_send_recv_restrictions", Debug::FATALERROR, Message::DOMAINLOADSENDRECV)) return false;
            $this->accountDefaultSendRecvRestrictions = new SendRecvRestrictions($sendRecvObj, $this);
        }
        return $this->accountDefaultSendRecvRestrictions;
    }
    /**
     * This function returns an object of MigrationData type for the selected domain
     * @return object MigrationData
     */
    public function configMigrationData() {
        if (!$this) return false;
        if (!is_object($this->migrationdata)) {
            $publicFolderObj = domain_migration_data_get($this->getDomainObj() , $this->getSessionObj());
            if (!Debug::checkError($publicFolderObj, "_p_migration_data", Debug::FATALERROR, Message::LOADMIGRATIONDATA)) return false;
            $this->migrationdata = new MigrationData($publicFolderObj, $this);
        }
        return $this->migrationdata;
    }
    /**
     * lists all the storage registered on AXIGEN for this domain
     * @return array
     */
    public function listStorages() {
        $newstorages = array();
        $storages = $this->storageInformation();
        foreach($storages as $storage) {
            unset($tmp);
            $tmp['usid'] = $storage['usid'];
            $tmp['location'] = $storage['location'];
            array_push($newstorages, $tmp);
        }
        return $newstorages;
    }
    /**
     * @ignore
     * compacts all the storage registered on a single file
     * @return bool
     * @note default will compact all the storage
     * @param $forced bool forced compact (default no) (optional parameter)
     * @param $usid string domain storage USID (default all storage will be compacted) (optional parameter)
     */
    public function compactStorage($forced = 0, $usid = null) {
        if (is_null($usid)) {
            $resp = compact_all_storages($this->getDomainObj() , $this->getSessionObj() , $forced);
        } else {
            $resp = compact_storage_by_usid($usid, $this->getDomainObj() , $this->getSessionObj() , $forced);
        }
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::COMPACTSTORAGE);
    }
    /**
     * upgrades the storage representation of configuration data and folders to the latest version
     * @return bool
     * @param $forced bool forced upgrade (optional)
     */
    public function upgradeStorage($forced = 0) {
        $resp = domain_storage_upgrade($this->getDomainObj() , $this->getSessionObj() , $forced);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::UPGRADESTORAGE);
    }
    /**
     * tries to recover lost accounts; the function will return the name of the newly-created account
     * @return string
     * @param $name string the account name that the server will try to repair
     */
    public function repairAccount($name) {
        $repairObj = domain_repair_account($name, $this->getDomainObj() , $this->getSessionObj());
        if (!Debug::checkError($repairObj, "_p_repaired_account", Debug::INFOERROR, Message::REPAIRACCOUNT)) return false;
        $name = repaired_account_name_get($repairObj);
        repaired_account_destroy($repairObj);
        return $name;
    }
    /**
     * synchronizes Domain Contacts folder with domain's objects contact information
     * @return bool
     */
    public function syncContacts() {
        $sync = domain_sync_contacts($this->getDomainObj() , $this->getSessionObj());
        return Debug::checkError($sync, 0, Debug::INFOERROR, Message::DOMAINSYNCCONTACT);
    }
    /**
     * migrates an account from another server to a local account
     * @return bool
     * @param $localAccount string the account name for migration
     * @param $remoteHost string the host of the migration server
     * @param $remotePort int the IMAP port of the migration server
     * @param $remoteUser string the IMAP username of the migration server
     * @param $remoteUserPassword string the IMAP password of the migration server
     * @param $ignoredFolders string/array specifies a list of folders which will not be migrated (either string for one folder, or an array for one or more) (optional parameter)
     * @param $overrideQuota bool specifies whether the mailbox quota should be overwritten (default: no) (optional parameter)
     * @param $deleteOriginal bool enables/disables the deletion of all migrated messages on the remote server (default: no) (optional parameter)
     * @param $structureOnly bool enables migration for the directory structure only (default: no) (optional parameter)
     */
    public function migrateAccount($localAccount, $remoteHost, $remotePort, $remoteUser, $remoteUserPassword, $ignoredFolders = null, $overrideQuota = 0, $deleteOriginal = 0, $structureOnly = 0) {
        $migrationObj = domain_migration_get($this->getSessionObj() , $this->getDomainObj());
        if (!Debug::checkError($migrationObj, "_p_migration", Debug::INFOERROR, Message::MIGRATEACCOUNT)) return false;
        $resp = migration_account_set($migrationObj, $localAccount);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::MIGRATEACCOUNT)) return false;
        $resp = migration_host_set($migrationObj, $remoteHost);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::MIGRATEACCOUNT)) return false;
        $resp = migration_port_set($migrationObj, $remotePort);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::MIGRATEACCOUNT)) return false;
        $resp = migration_user_set($migrationObj, $remoteUser);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::MIGRATEACCOUNT)) return false;
        $resp = migration_password_set($migrationObj, $remoteUserPassword);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::MIGRATEACCOUNT)) return false;
        if (!is_null($ignoredFolders)) {
            if (is_array($ignoredFolders)) {
                foreach($ignoredFolders as $folder) {
                    $resp = migration_set_ignored_folder($migrationObj, $folder);
                    if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::MIGRATEACCOUNT)) return false;
                }
            } else {
                $resp = migration_set_ignored_folder($migrationObj, $ignoredFolders);
                if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::MIGRATEACCOUNT)) return false;
            }
        }
        $resp = migration_override_quota_set($migrationObj, $overrideQuota);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::MIGRATEACCOUNT)) return false;
        $resp = migration_delete_original_set($migrationObj, $deleteOriginal);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::MIGRATEACCOUNT)) return false;
        $resp = migration_structure_only_set($migrationObj, $structureOnly);
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::MIGRATEACCOUNT)) return false;
        $resp = migration_migrate($migrationObj, $this->getSessionObj());
        migration_destroy($migrationObj);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::MIGRATEACCOUNT);
    }

    /**
     * this method must be called if one of the members has been changed
     * @return bool
     */
    public function save() {
        if (!$this) return false;
        $resp = domain_save($this->getDomainObj() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SAVEDOMAINDATA);
    }

    /**
     * resets the ldap syncronization (any syncronization in progress must be stopped first)
     * @return bool
     */
    public function resetLdapSynchronization() {
        if (!$this) return false;
        $resp = domain_reset_ldapsynchronization($this->getDomainObj() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::DOMAINRESTLDAPSYNC);
    }

    /**
Set member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>name</td><td>the domain name</td>
<tr><td>assignedIp</td><td>the domain assigned IP</td>
<tr><td>appenderText</td><td>the domain appender text</td>
<tr><td>enableSmtpIncoming</td><td>SMTP Incoming status</td>
<tr><td>enableSmtpOutgoing</td><td>SMTP Outgoing status</td>
<tr><td>enablePop3</td><td>POP3 status</td>
<tr><td>enableRpop</td><td>RPOP status</td>
<tr><td>enableImap</td><td>IMAP status</td>
<tr><td>enableWebmail</td><td>Webmail status</td>
<tr><td>showWebmailLogin</td><td>displays this domain at Webmail login</td>
<tr><td>publishRcptContacts</td><td>switch indicating if domain recipients contacts are published</td>
<tr><td>enableAppender</td><td>the message appender</td>
<tr><td>catchAllType</td><td>the type of Catch-All behavior (one of "disabled", "account" or "publicFolder")</td>
<tr><td>catchAllAccountName</td><td>the name of the account used to store all messages with unknown recipient</td>
<tr><td>catchAllFolderName</td><td>the name of the folder used to store all messages with unknown recipient</td>
<tr><td>enableLDAPSync</td><td>enables/disables LDAP-AXIGEN synchronization</td>
<tr><td>ldapSyncConnectorName</td><td>the name of the LDAP connector to use</td>
<tr><td>customerReference</td><td>the customer reference for use with external billing-like systems</td>
<tr><td>defaultLanguage</td><td>the default language</td>
<tr><td>defaultTimeZone</td><td>the default timezone</td>
<tr><td>createUsersFromLdap</td><td>enabled/disabled auto-creation of users authenticated from LDAP</td>
<tr><td>disposableMetadataQuotaThreshold</td><td>the disposable meta-data quota threshold</td>
</table>
     */
    public function __set($varName, $varValue) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "defaulttimezone":
                return domain_default_time_zone_set($this->getDomainObj() , $varValue);
            break;
            case "defaultlanguage":
                return domain_default_language_set($this->getDomainObj() , $varValue);
            break;
            case "name":
                $resp = domain_name_set($this->getDomainObj() , $varValue);
            break;
            case "customerreference":
                $resp = domain_customer_reference_set($this->getDomainObj() , $varValue);
            break;
            case "assignedip":
                $resp = domain_assigned_ip_set($this->getDomainObj() , $varValue);
            break;
            case "appendertext":
                $resp = domain_appender_text_set($this->getDomainObj() , $varValue);
            break;
            case "showwebmaillogin":
                $resp = domain_show_webmail_login_set($this->getDomainObj() , $varValue);
            break;
            case "publishrcptcontacts":
                $resp = domain_publish_rcpt_contacts_set($this->getDomainObj() , $varValue);
            break;
            case "enableappender":
                $resp = domain_appender_enabled_set($this->getDomainObj() , $varValue);
            break;
            case "catchalltype":
                $resp = domain_catch_all_type_set($this->getDomainObj() , $varValue);
            break;
            case "catchallaccountname":
                $resp = domain_catch_all_account_set($this->getDomainObj() , $varValue);
            break;
            case "catchallfoldername":
                $resp = domain_catch_all_folder_set($this->getDomainObj() , $varValue);
            break;
            case "enablesmtpincoming":
                $resp = services_smtp_incoming_set_enable($this->getDomainServicesObj() , $varValue);
            break;
            case "enablesmtpoutgoing":
                $resp = services_smtp_outgoing_set_enable($this->getDomainServicesObj() , $varValue);
            break;
            case "enablepop3":
                $resp = services_pop3_set_enable($this->getDomainServicesObj() , $varValue);
            break;
            case "enablerpop":
                $resp = services_rpop_set_enable($this->getDomainServicesObj() , $varValue);
            break;
            case "enableimap":
                $resp = services_imap_set_enable($this->getDomainServicesObj() , $varValue);
            break;
            case "enablewebmail":
                $resp = services_webmail_set_enable($this->getDomainServicesObj() , $varValue);
            break;
            case "enableldapsync";
                $resp = domain_enable_ldap_sync_set($this->getDomainObj() , $varValue);
            break;
            case "ldapsyncconnectorname";
                $resp = domain_ldap_sync_connector_name_set($this->getDomainObj() , $varValue);
            break;
            case "createusersfromldap";
                $resp = domain_create_users_from_ldap_set($this->getDomainObj() , $varValue);
            break;
            case "disposablemetadataquotathreshold";
                $resp = domain_disposable_metadata_quota_threshold_set($this->getDomainObj() , $varValue);
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::SETDOMAINVARERROR);
                return;
        }
    return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETDOMAINVARERROR);
}
    /**
Get member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>name</td><td>the domain name</td>
<tr><td>assignedIp</td><td>the domain assigned IP</td>
<tr><td>appenderText</td><td>the domain appender text</td>
<tr><td>enableSmtpIncoming</td><td>SMTP Incoming status</td>
<tr><td>enableSmtpOutgoing</td><td>SMTP Outgoing status</td>
<tr><td>enablePop3</td><td>POP3 status</td>
<tr><td>enableRpop</td><td>RPOP status</td>
<tr><td>enableImap</td><td>IMAP status</td>
<tr><td>enableWebmail</td><td>Webmail status</td>
<tr><td>showWebmailLogin</td><td>displays this domain at Webmail login</td>
<tr><td>publishRcptContacts</td><td>switch indicating if domain recipients contacts are published</td>
<tr><td>enableAppender</td><td>the message appender</td>
<tr><td>catchAllType</td><td>the type of Catch-All behavior (one of "disabled", "account" or "publicFolder")</td>
<tr><td>catchAllAccountName</td><td>the name of the account used to store all messages with unknown recipient</td>
<tr><td>catchAllFolderName</td><td>the name of the folder used to store all messages with unknown recipient</td>
<tr><td>enableLDAPSync</td><td>enables/disables LDAP-AXIGEN synchronization</td>
<tr><td>ldapSyncConnectorName</td><td>the name of the LDAP connector to use</td>
<tr><td>customerReference</td><td>the customer reference for use with external billing-like systems</td>
<tr><td>defaultLanguage</td><td>the default language</td>
<tr><td>defaultTimeZone</td><td>the default timezone</td>
<tr><td>createUsersFromLdap</td><td>enabled/disabled auto-creation of users authenticated from LDAP</td>
<tr><td>disposableMetadataQuotaThreshold</td><td>the disposable meta-data quota threshold</td>
</table>
     */
public function __get($varName) {
    if (!$this) return false;
    switch (strtolower($varName)) {
        case "defaulttimezone":
            return domain_default_time_zone_get($this->getDomainObj());
        break;
        case "defaultlanguage":
            return domain_default_language_get($this->getDomainObj());
        break;
        case "name":
            return domain_name_get($this->getDomainObj());
        break;
        case "customerreference":
            return domain_customer_reference_get($this->getDomainObj());
        break;
        case "assignedip":
            return domain_assigned_ip_get($this->getDomainObj());
        break;
        case "appendertext":
            return domain_appender_text_get($this->getDomainObj());
        break;
        case "sharedfoldersnamespace":
            return domain_shared_folders_namespace_get($this->getDomainObj());
        break;
        case "showwebmaillogin":
            return domain_show_webmail_login_get($this->getDomainObj());
        break;
        case "publishrcptcontacts":
            return domain_publish_rcpt_contacts_get($this->getDomainObj());
        break;
        case "enableappender":
            return domain_appender_enabled_get($this->getDomainObj());
        break;
        case "catchalltype":
            return domain_catch_all_type_get($this->getDomainObj());
        break;
        case "catchallaccountname":
            return domain_catch_all_account_get($this->getDomainObj());
        break;
        case "catchallfoldername":
            return domain_catch_all_folder_get($this->getDomainObj());
        break;
        case "enablesmtpincoming":
            return services_smtp_incoming_is_enable($this->getDomainServicesObj());
        break;
        case "enablesmtpoutgoing":
            return services_smtp_outgoing_is_enable($this->getDomainServicesObj());
        break;
        case "enablepop3":
            return services_pop3_is_enable($this->getDomainServicesObj());
        break;
        case "enablerpop":
            return services_rpop_is_enable($this->getDomainServicesObj());
        break;
        case "enableimap":
            return services_imap_is_enable($this->getDomainServicesObj());
        break;
        case "enablewebmail":
            return services_webmail_is_enable($this->getDomainServicesObj());
        break;
        case "enableldapsync":
            return domain_enable_ldap_sync_get($this->getDomainObj());
        break;
        case "ldapsyncconnectorname":
            return domain_ldap_sync_connector_name_get($this->getDomainObj());
        break;
        case "createusersfromldap":
            return domain_create_users_from_ldap_get($this->getDomainObj());
        case "disposablemetadataquotathreshold";
            return domain_disposable_metadata_quota_threshold_get($this->getDomainObj());
        break;
        default:
            Debug::checkError("0", "1", Debug::INFOERROR, Message::GETDOMAINVARERROR);
    }
   }
    /*    
     * purge mails from specified folders of all users from selected domain
     * @param $folders string the folders to purge (list is separated by , and names with spaces are between brackets)
     * @param $conditon string the purge condition (optional, default: ALL)
     * @return bool
     */
    public function purgeAccountFolders($folders, $condition = null) {
        if (!$this) return false;
        if (!is_string($folders)) return false;
        $resp = domain_purge_account_folders($this->getDomainObj(), $this->getSessionObj() , $folders, $condition);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::PURGEACCOUNTFOLDERS);
    }

    /*    
     * purge mails from specified public folders from selected domain
     * @param $folders string the public folders to purge (list is separated by , and names with spaces are between brackets)
     * @param $conditon string the purge condition (optional, default: ALL)
     * @return bool
     */
    public function purgePublicFolders($folders, $condition = null) {
        if (!$this) return false;
        if (!is_string($folders)) return false;
        $resp = domain_purge_public_folders($this->getDomainObj(), $this->getSessionObj() , $folders, $condition);
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::PURGEPUBLICFOLDERS);
    }
}

/** @} */ // end of group
?>
