<?php
/**
 * this is the object containing the list data for the selected mail list
 * \ingroup updateDomain
 * \defgroup updateList updateList
 * @{
 */
class MailList {
    private $maillist, $parent, $services, $limits, $filters, $quotas, $webmaildata;
    public function __construct($maillistObj, $parentObj) {
        $this->maillist = $maillistObj;
        $this->parent = $parentObj;
    }
    public function __destruct() {
        maillist_destroy($this->getMailListObj());
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    public function getMailListObj() {
        return $this->maillist;
    }
    public function getMailListServicesObj() {
        if (!is_resource($this->services)) {
            $this->services = maillist_services_get($this->getMailListObj());
            if (!Debug::checkError($this->services, "_p_services", Debug::FATALERROR, Message::GETLISTSSERVICES)) return false;
        }
        return $this->services;
    }
    /**
     * lists the available users for this list
     * @return array
     */
    public function listUsers() {
        $userlist = array();
        $userlistObj = list_user_iterator_begin($this->getMailListObj());
        if (!Debug::checkError($userlistObj, "_p_list_user_iterator", Debug::INFOERROR, Message::LISTUSERSMAILLIST)) return false;
        while (list_user_iterator_has_value($userlistObj)) {
            $userObj = list_user_iterator_value($userlistObj);
            unset($tmp);
            $tmp['email'] = trim(list_user_get_email($userObj));
            $tmp['name'] = trim(list_user_get_name($userObj));
            array_push($userlist, $tmp);
            list_user_iterator_next($userlistObj);
        }
        list_user_iterator_destroy($userlistObj);
        return $userlist;
    }
    /**
     * shows the list of headers that will be removed from a mail
     * @return array
     */
    public function listRemoveHeaders() {
        $listremoveheaders = array();
        $removeHeaderIterObj = remove_header_iterator_begin($this->getMailListObj());
        if (!Debug::checkError($removeHeaderIterObj, "_p_remove_header_iterator", Debug::INFOERROR, Message::LISTREMOVEHEADERSMAILLIST)) return false;
        while (remove_header_iterator_has_value($removeHeaderIterObj)) {
            $obj = remove_header_iterator_value($removeHeaderIterObj);
            array_push($listremoveheaders, remove_header_name_get($obj));
            remove_header_iterator_next($removeHeaderIterObj);
        }
        remove_header_iterator_destroy($removeHeaderIterObj);
        return $listremoveheaders;
    }
    /**
     * shows registry information
     * @return array
     */
    public function registryInformation() {
        $regObj = maillist_registry_information_get($this->getMailListObj() , $this->getSessionObj());
        if (!Debug::checkError($regObj, "_p_registry_information", Debug::INFOERROR, Message::LISTTREGISTRYINFO)) return false;
        $reg['creationDate'] = registry_information_creation_date_get($regObj);
        $reg['modificationDate'] = registry_information_modification_date_get($regObj);
        $reg['pop3LastLoginDate'] = registry_information_pop3_last_login_date_get($regObj);
        $reg['pop3LastLoginIp'] = registry_information_pop3_last_login_ip_get($regObj);
        $reg['imapLastLoginDate'] = registry_information_imap_last_login_date_get($regObj);
        $reg['imapLastLoginIp'] = registry_information_imap_last_login_ip_get($regObj);
        $reg['webmailLastLoginDate'] = registry_information_webmail_last_login_date_get($regObj);
        $reg['webmailLastLoginIp'] = registry_information_webmail_last_login_ip_get($regObj);
        registry_information_destroy($regObj);
        return $reg;
    }
    /**
     * this method returns an object of WebmailData for the selected list
     * @return object WebmailData
     */
    public function configWebmailData() {
        if (!$this) return false;
        if (!is_object($this->webmaildata)) {
            $webmailDataObj = maillist_webmaildata_get($this->getMailListObj() , $this->getSessionObj());
            if (!Debug::checkError($webmailDataObj, "_p_webmaildata", Debug::FATALERROR, Message::LOADLISTWEBMAILDATA)) return false;
            $this->webmaildata = new WebmailData($webmailDataObj, $this);
        }
        return $this->webmaildata;
    }
    /**
     * this method returns an object of Filters for the selected list
     * @return object Filters
     */
    public function configFilters() {
        if (!$this) return false;
        if (!is_object($this->filters)) {
            $filterObj = maillist_filters_get($this->getMailListObj() , $this->getSessionObj());
            if (!Debug::checkError($filterObj, "_p_filters", Debug::FATALERROR, Message::LOADLISTFILTERS)) return false;
            $this->filters = new Filters($filterObj, $this);
        }
        return $this->filters;
    }
    /**
     * this method returns an object of Quotas for the selected list
     * @return object Quotas
     */
    public function configQuotas() {
        if (!$this) return false;
        if (!is_object($this->quotas)) {
            $quotasObj = maillist_quotas_get($this->getMailListObj() , $this->getSessionObj());
            if (!Debug::checkError($quotasObj, "_p_quotas", Debug::FATALERROR, Message::LOADLISTQUOTAS)) return false;
            $this->quotas = new Quotas($quotasObj, $this);
        }
        return $this->quotas;
    }
    /**
     * this method returns an object of Limits for the selected list
     * @return object Limits
     */
    public function configLimits() {
        if (!$this) return false;
        if (!is_object($this->limits)) {
            $limitsObj = maillist_limits_get($this->getMailListObj() , $this->getSessionObj());
            if (!Debug::checkError($limitsObj, "_p_limits", Debug::FATALERROR, Message::LOADLISTTLIMITS)) return false;
            $this->limits = new Limits($limitsObj, $this);
        }
        return $this->limits;
    }
    /**
     * adds an user to the list
     * @return bool
     * @param $userEmail string New user email address
     * @param $userName string New user name
     */
    public function addUser($userEmail, $userName) {
        $resp = list_user_add($this->getMailListObj() , $userEmail, $userName);
        Debug::checkError($resp, 0, Debug::INFOERROR, Message::ADDLISTUSER);
        return $this->save();
    }
    /**
     * removes an user from the list
     * @return bool
     * @param $userEmail string User email address to be removed
     */
    public function removeUser($userEmail) {
        $resp = maillist_list_user_remove_by_email($this->getMailListObj() , $userEmail);
        Debug::checkError($resp, 0, Debug::INFOERROR, Message::REMOVELISTUSER);
        return $this->save();
    }
    /**
     * updates a user name
     * @return bool
     * @param $userEmail string User email address to be updated
     * @param $newName string User new name
     */
    public function updateUser($userEmail, $newName) {
        $userObj = maillist_list_user_get_by_email($this->getMailListObj() , $userEmail);
        $resp = list_user_change_name($userObj, $newName);
        Debug::checkError($resp, 0, Debug::INFOERROR, Message::UPDATELISTUSER);
        return $this->save();
    }
    /**
     * adds a header to the list of headers to be removed
     * @return bool
     * @param $header string Header to be added to the list
     */
    public function addRemoveHeader($header) {
        $resp = remove_header_add($this->getMailListObj() , $header);
        Debug::checkError($resp, 0, Debug::INFOERROR, Message::ADDLISTREMOVEHEADER);
        return $this->save();
    }
    /**
     * removes a header from the list of headers to be removed
     * @return bool
     * @param $header string Header to be removed from the list
     */
    public function removeRemoveHeader($header) {
        $resp = remove_header_remove_by_name($this->getMailListObj() , $header);
        Debug::checkError($resp, 0, Debug::INFOERROR, Message::REMOVELISTREMOVEHEADER);
        return $this->save();
    }
    /**
     * this method must be called if one of the members has been changed
     * @return bool
     */
    public function save() {
        if (!$this) return false;
        $resp = maillist_save($this->getMailListObj() , $this->getSessionObj());
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SAVELISTSDATA);
    }
    /**
Set member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>name</td>
<td>the name of the list</td>
<tr><td>password</td>
<td>the list's mailbox access password</td>
<tr><td>subscribeRcpt</td>
<td>the RCPT used for subscription</td>
<tr><td>unsubscribeRcpt</td>
<td>the RCPT used for unsubscription</td>
<tr><td>requestRcpt</td>
<td>the RCPT used for making a request</td>
<tr><td>enabledRcpts</td>
<td>the RCPTs enabled for this list</td>
<tr><td>description</td>
<td>the description of the list</td>
<tr><td>adminConfirm</td>
<td>the adminConfirm parameter</td>
<tr><td>senderAllow</td>
<td>the senderAllow parameter</td>
<tr><td>moderate</td>
<td>the moderate parameter</td>
<tr><td>ctypeAllow</td>
<td>the ctypeAllow parameter</td>
<tr><td>adminEmail</td>
<td>the email for the admin</td>
<tr><td>addHeader</td>
<td>the headers that will be added to the mail</td>
<tr><td>bodyBegin</td>
<td>the text that will be inserted before the body</td>
<tr><td>bodyEnd</td>
<td>the text that will be added to the body of the mail</td>
<tr><td>unknownCommand</td>
<td>the description of the error in case of an unknown command</td>
<tr><td>invalidUserName</td>
<td>the description of the error in case of an invalid user name</td>
<tr><td>notAUser</td>
<td>the description of the error in case the user does not belong to the list</td>
<tr><td>badConfirmation</td>
<td>the description of the error in case of a bad confirmation</td>
<tr><td>userAlreadySubscribed</td>
<td>the description of the error in case the user already exists</td>
<tr><td>invalidFormat</td>
<td>the description of the error in case of an invalid format</td>
<tr><td>requestNeedsConfirmation</td>
<td>the template that will ask the user for a confirmation</td>
<tr><td>requestNeedsAdminConfirmation</td>
<td>the template that will tell the user to wait for confirmation from the admin</td>
<tr><td>autoRejectResponse</td>
<td>the template that will tell the user that his mail is rejected</td>
<tr><td>welcome</td>
<td>the template that will tell the user that he has been created</td>
<tr><td>goodbye</td>
<td>the template that will tell the user that he has been deleted</td>
<tr><td>subscribeDenied</td>
<td>the template that will tell the user that he has not been created</td>
<tr><td>publishContactInfo</td>
<td>the enabled/disabled publish contact info</td>
<tr><td>enableSmtpIncoming</td>
<td>the enable/disable status for SMTP Incoming</td>
<tr><td>enableSmtpOutgoing</td>
<td>the enable/disable status for SMTP Outgoing</td>
<tr><td>enablePop3</td>
<td>the enable/disable status for POP3</td>
<tr><td>enableImap</td>
<td>the enable/disable status for IMAP</td>
<tr><td>enableWebmail</td>
<td>the enable/disable status for Webmail</td>
<tr><td>enableRpop</td>
<td>the enable/disable status for RPOP</td>
</table>
     */
    public function __set($varName, $varValue) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "name":
                $resp = maillist_name_set($this->getMailListObj() , $varValue);
            break;
            case "password":
                $resp = maillist_password_set($this->getMailListObj() , $varValue);
            break;
            case "subscribercpt":
                $resp = maillist_subscribe_rcpt_set($this->getMailListObj() , $varValue);
            break;
            case "unsubscribercpt":
                $resp = maillist_unsubscribe_rcpt_set($this->getMailListObj() , $varValue);
            break;
            case "requestrcpt":
                $resp = maillist_request_rcpt_set($this->getMailListObj() , $varValue);
            break;
            case "enabledrcpts":
                $resp = maillist_enabled_rcpts_set($this->getMailListObj() , $varValue);
            break;
            case "description":
                $resp = maillist_description_set($this->getMailListObj() , $varValue);
            break;
            case "adminconfirm":
                $resp = maillist_admin_confirm_set($this->getMailListObj() , $varValue);
            break;
            case "senderallow":
                $resp = maillist_sender_allow_set($this->getMailListObj() , $varValue);
            break;
            case "moderate":
                $resp = maillist_moderate_set($this->getMailListObj() , $varValue);
            break;
            case "ctypeallow":
                $resp = maillist_ctype_allow_set($this->getMailListObj() , $varValue);
            break;
            case "adminemail":
                $resp = maillist_admin_email_set($this->getMailListObj() , $varValue);
            break;
            case "addheader":
                $resp = maillist_add_header_set($this->getMailListObj() , $varValue);
            break;
            case "bodybegin":
                $resp = maillist_body_begin_set($this->getMailListObj() , $varValue);
            break;
            case "bodyend":
                $resp = maillist_body_end_set($this->getMailListObj() , $varValue);
            break;
            case "unknowncommand":
                $resp = maillist_unknown_command_set($this->getMailListObj() , $varValue);
            break;
            case "invalidusername":
                $resp = maillist_invalid_user_name_set($this->getMailListObj() , $varValue);
            break;
            case "notauser":
                $resp = maillist_not_a_user_set($this->getMailListObj() , $varValue);
            break;
            case "badconfirmation":
                $resp = maillist_bad_confirmation_set($this->getMailListObj() , $varValue);
            break;
            case "useralreadysubscribed":
                $resp = maillist_user_already_subscribed_set($this->getMailListObj() , $varValue);
            break;
            case "invalidformat":
                $resp = maillist_invalid_format_set($this->getMailListObj() , $varValue);
            break;
            case "requestneedsconfirmation":
                $resp = maillist_request_needs_confirmation_set($this->getMailListObj() , $varValue);
            break;
            case "requestneedsadminconfirmation":
                $resp = maillist_request_needs_admin_confirmation_set($this->getMailListObj() , $varValue);
            break;
            case "autorejectresponse":
                $resp = maillist_auto_reject_response_set($this->getMailListObj() , $varValue);
            break;
            case "welcome":
                $resp = maillist_welcome_set($this->getMailListObj() , $varValue);
            break;
            case "goodbye":
                $resp = maillist_goodbye_set($this->getMailListObj() , $varValue);
            break;
            case "subscribedenied":
                $resp = maillist_subscribe_denied_set($this->getMailListObj() , $varValue);
            break;
            case "publishcontactinfo":
                $resp = maillist_publish_contact_info_set($this->getGroupObj() , $varValue);
            break;
            case "enablesmtpincoming":
                return services_smtp_incoming_set_enable($this->getMailListServicesObj() , $varValue);
            break;
            case "enablesmtpoutgoing":
                return services_smtp_outgoing_set_enable($this->getMailListServicesObj() , $varValue);
            break;
            case "enablepop3":
                return services_pop3_set_enable($this->getMailListServicesObj() , $varValue);
            break;
            case "enablerpop":
                return services_rpop_set_enable($this->getMailListServicesObj() , $varValue);
            break;
            case "enableimap":
                return services_imap_set_enable($this->getMailListServicesObj() , $varValue);
            break;
            case "enablewebmail":
                $resp = services_webmail_set_enable($this->getMailListServicesObj() , $varValue);
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::SETMAILLISTVARERROR);
                return;
        }
        return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETMAILLISTVARERROR);
    }
    /**
Get member.

<table>
<tr><th>member</th><th>description</th>
<tr><td>name</td>
<td>the name of the list</td>
<tr><td>password</td>
<td>the list's mailbox access password</td>
<tr><td>subscribeRcpt</td>
<td>the RCPT used for subscription</td>
<tr><td>unsubscribeRcpt</td>
<td>the RCPT used for unsubscription</td>
<tr><td>requestRcpt</td>
<td>the RCPT used for making a request</td>
<tr><td>enabledRcpts</td>
<td>the RCPTs enabled for this list</td>
<tr><td>description</td>
<td>the description of the list</td>
<tr><td>adminConfirm</td>
<td>the adminConfirm parameter</td>
<tr><td>senderAllow</td>
<td>the senderAllow parameter</td>
<tr><td>moderate</td>
<td>the moderate parameter</td>
<tr><td>ctypeAllow</td>
<td>the ctypeAllow parameter</td>
<tr><td>adminEmail</td>
<td>the email for the admin</td>
<tr><td>addHeader</td>
<td>the headers that will be added to the mail</td>
<tr><td>bodyBegin</td>
<td>the text that will be inserted before the body</td>
<tr><td>bodyEnd</td>
<td>the text that will be added to the body of the mail</td>
<tr><td>unknownCommand</td>
<td>the description of the error in case of an unknown command</td>
<tr><td>invalidUserName</td>
<td>the description of the error in case of an invalid user name</td>
<tr><td>notAUser</td>
<td>the description of the error in case the user does not belong to the list</td>
<tr><td>badConfirmation</td>
<td>the description of the error in case of a bad confirmation</td>
<tr><td>userAlreadySubscribed</td>
<td>the description of the error in case the user already exists</td>
<tr><td>invalidFormat</td>
<td>the description of the error in case of an invalid format</td>
<tr><td>requestNeedsConfirmation</td>
<td>the template that will ask the user for a confirmation</td>
<tr><td>requestNeedsAdminConfirmation</td>
<td>the template that will tell the user to wait for confirmation from the admin</td>
<tr><td>autoRejectResponse</td>
<td>the template that will tell the user that his mail is rejected</td>
<tr><td>welcome</td>
<td>the template that will tell the user that he has been created</td>
<tr><td>goodbye</td>
<td>the template that will tell the user that he has been deleted</td>
<tr><td>subscribeDenied</td>
<td>the template that will tell the user that he has not been created</td>
<tr><td>publishContactInfo</td>
<td>the enabled/disabled publish contact info</td>
<tr><td>enableSmtpIncoming</td>
<td>the enable/disable status for SMTP Incoming</td>
<tr><td>enableSmtpOutgoing</td>
<td>the enable/disable status for SMTP Outgoing</td>
<tr><td>enablePop3</td>
<td>the enable/disable status for POP3</td>
<tr><td>enableImap</td>
<td>the enable/disable status for IMAP</td>
<tr><td>enableWebmail</td>
<td>the enable/disable status for Webmail</td>
<tr><td>enableRpop</td>
<td>the enable/disable status for RPOP</td>
</table>
     */
    public function __get($varName) {
        if (!$this) return false;
        switch (strtolower($varName)) {
            case "name":
                return maillist_name_get($this->getMailListObj());
            break;
            case "subscribercpt":
                return maillist_subscribe_rcpt_get($this->getMailListObj());
            break;
            case "unsubscribercpt":
                return maillist_unsubscribe_rcpt_get($this->getMailListObj());
            break;
            case "requestrcpt":
                return maillist_request_rcpt_get($this->getMailListObj());
            break;
            case "enabledrcpts":
                return maillist_enabled_rcpts_get($this->getMailListObj());
            break;
            case "description":
                return maillist_description_get($this->getMailListObj());
            break;
            case "adminconfirm":
                return maillist_admin_confirm_get($this->getMailListObj());
            break;
            case "senderallow":
                return maillist_sender_allow_get($this->getMailListObj());
            break;
            case "moderate":
                return maillist_moderate_get($this->getMailListObj());
            break;
            case "ctypeallow":
                return maillist_ctype_allow_get($this->getMailListObj());
            break;
            case "adminemail":
                return maillist_admin_email_get($this->getMailListObj());
            break;
            case "addheader":
                return maillist_add_header_get($this->getMailListObj());
            break;
            case "bodybegin":
                return maillist_body_begin_get($this->getMailListObj());
            break;
            case "bodyend":
                return maillist_body_end_get($this->getMailListObj());
            break;
            case "unknowncommand":
                return maillist_unknown_command_get($this->getMailListObj());
            break;
            case "invalidusername":
                return maillist_invalid_user_name_get($this->getMailListObj());
            break;
            case "notauser":
                return maillist_not_a_user_get($this->getMailListObj());
            break;
            case "badconfirmation":
                return maillist_bad_confirmation_get($this->getMailListObj());
            break;
            case "useralreadysubscribed":
                return maillist_user_already_subscribed_get($this->getMailListObj());
            break;
            case "invalidformat":
                return maillist_invalid_format_get($this->getMailListObj());
            break;
            case "requestneedsconfirmation":
                return maillist_request_needs_confirmation_get($this->getMailListObj());
            break;
            case "requestneedsadminconfirmation":
                return maillist_request_needs_admin_confirmation_get($this->getMailListObj());
            break;
            case "autorejectresponse":
                return maillist_auto_reject_response_get($this->getMailListObj());
            break;
            case "welcome":
                return maillist_welcome_get($this->getMailListObj());
            break;
            case "goodbye":
                return maillist_goodbye_get($this->getMailListObj());
            break;
            case "subscribedenied":
                return maillist_subscribe_denied_get($this->getMailListObj());
            break;
            case "publishcontactinfo":
                return maillist_publish_contact_info_get($this->getMailListObj());
            break;
            case "enablesmtpincoming":
                return services_smtp_incoming_is_enable($this->getMailListServicesObj());
            break;
            case "enablesmtpoutgoing":
                return services_smtp_outgoing_is_enable($this->getMailListServicesObj());
            break;
            case "enablepop3":
                return services_pop3_is_enable($this->getMailListServicesObj());
            break;
            case "enablerpop":
                return services_rpop_is_enable($this->getMailListServicesObj());
            break;
            case "enableimap":
                return services_imap_is_enable($this->getMailListServicesObj());
            break;
            case "enablewebmail":
                return services_webmail_is_enable($this->getMailListServicesObj());
            break;
            default:
                Debug::checkError("0", "1", Debug::INFOERROR, Message::GETMAILLISTVARERROR);
                return;
        }
    }
}
/** @} */ // end of group
?>
