<?php
/** 
 * \ingroup viewQueue
 * \defgroup enterQuarantine enterQuarantine
 * @{
 */
class Quarantine {
    private $quarantine, $parent, $filterObj;
    public function __construct($quarantineObj, $parentObj) {
        $this->quarantine = $quarantineObj;
        $this->parent = $parentObj;
    }
    public function __destruct() {
        quarantine_destroy($this->getQuarantineObj());
        if (is_resource($this->getFilterObj())) {
            quarantine_filter_destroy($this->getFilterObj());
        }
    }
    public function getQuarantineObj() {
        return $this->quarantine;
    }
    public function getFilterObj() {
        return $this->filterObj;
    }
    public function getSessionObj() {
        if ($this->parent == null) return $this->session;
        return $this->parent->getSessionObj();
    }
    /**
     * returns an array with all the emails from the quarantine
     * @return array
     */
    public function listQuarantineEMails() {
        if (!$this) return false;
        $quarantine = array();
        $resp = quarantine_load_items($this->getQuarantineObj() , $this->getSessionObj());
        if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::LOADQUARANTINEITEMS)) return false;
        $quarantineIterObj = quarantine_item_iterator_begin($this->getQuarantineObj());
        if (!Debug::checkError($quarantineIterObj, "_p_quarantine_item_iterator", Debug::INFOERROR, Message::LISTQUARANTINEMAILS)) return false;
        while (quarantine_item_iterator_has_value($quarantineIterObj)) {
            $quarantineObj = quarantine_item_iterator_value($quarantineIterObj);
            unset($tmp);
            $tmp['id'] = quarantine_item_id_get($quarantineObj);
            $tmp['sender'] = quarantine_item_sender_get($quarantineObj);
            $tmp['recipients'] = quarantine_item_recipients_get($quarantineObj);
            $tmp['status'] = quarantine_item_status_get($quarantineObj);
            $tmp['size'] = quarantine_item_size_get($quarantineObj);
            $tmp['nextSchedule'] = quarantine_item_next_schedule_get($quarantineObj);
            array_push($quarantine, $tmp);
            quarantine_item_iterator_next($quarantineIterObj);
        }
        quarantine_item_iterator_destroy($quarantineIterObj);
        return $quarantine;
    }
    private function startFilter() {
        $resp = quarantine_create_filter($this->getQuarantineObj());
        Debug::checkError($resp, "_p_quarantine_filter", Debug::INFOERROR, Message::QUARANTINEFILTER);
        $this->filterObj = $resp;
    }
    /**
     * clears the already set filters
     * @return bool
     */
    public function clearFilters() {
        if (!$this) return false;
        if (is_resource($this->getFilterObj())) {
            quarantine_filter_destroy($this->getFilterObj());
            $this->filterObj = null;
        }
        $this->startFilter();
        return is_resource($this->getFilterObj());
    }
    /**
     * sets the filter size restriction
     * @return bool
     * @param $size int the message size
     * @param $compareType string type of comparison (equal , less, more)
     * @param $sizeType string type of size (B - bytes, KB - kilobytes, MB - megabytes)
     */
    public function imposeSizeRestriction($size, $compareType = "equal", $sizeType = "kb") {
        if (!$this) return false;
        switch (strtolower($sizeType)) {
            case "b":
                $b = $size;
                $kb = $mb = 0;
            break;
            case "kb":
                $kb = $size;
                $b = $mb = 0;
            break;
            case "mb":
                $mb = $size;
                $kb = $b = 0;
            break;
            default:
                return false;
        }
        switch (strtolower($compareType)) {
            case "equal":
                $how = 0;
            break;
            case "less":
                $how = -1;
            break;
            case "more";
            $how = 1;
        break;
        default:
            return false;
    }
    if (!is_resource($this->getFilterObj())) $this->startFilter();
    $resp = quarantine_impose_size_restriction($this->getFilterObj() , $mb, $kb, $b, $how);
    return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETQUARANTINEFILTERS);
}
/**
 * sets the filter age restriction
 * @return bool
 * @param $day int number of days
 * @param $hours int number of hours
 * @param $min int number of minutes
 * @param $sec int number of seconds
 * @param $compareType string type of comparison (equal , less, more)
 */
public function imposeAgeRestriction($day = 0, $hours = 0, $min = 0, $sec = 0, $compareType = "equal") {
    if (!$this) return false;
    switch (strtolower($compareType)) {
        case "equal":
            $how = 0;
        break;
        case "less":
            $how = -1;
        break;
        case "more";
        $how = 1;
    break;
    default:
        return false;
}
if (!is_resource($this->getFilterObj())) $this->startFilter();
$resp = quarantine_impose_age_restriction($this->getFilterObj() , $day, $hours, $min, $sec, $how);
return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETQUARANTINEFILTERS);
}
/**
 * sets the filter retries restriction
 * @return bool
 * @param $nrOfRetries int number of retries
 * @param $compareType string type of comparison (equal , less, more)
 */
public function imposeRetriesRestriction($nrOfRetries, $compareType = "equal") {
    if (!$this) return false;
    switch (strtolower($compareType)) {
        case "equal":
            $how = 0;
        break;
        case "less":
            $how = -1;
        break;
        case "more";
        $how = 1;
    break;
    default:
        return false;
}
if (!is_resource($this->getFilterObj())) $this->startFilter();
$resp = quarantine_impose_retries_restriction($this->getFilterObj() , $nrOfRetries, $how);
return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETQUARANTINEFILTERS);
}
/**
 * sets the filter next schedule restriction
 * @return bool
 * @param $date string next schedule date (ex: 2 Jan 2007 17:34)
 * @param $compareType string type of comparison (equal , less, more)
 */
public function imposeNextScheduleRestriction($date, $compareType) {
    if (!$this) return false;
    switch (strtolower($compareType)) {
        case "equal":
            $how = 0;
        break;
        case "less":
            $how = -1;
        break;
        case "more";
        $how = 1;
    break;
    default:
        return false;
}
if (!is_resource($this->getFilterObj())) $this->startFilter();
$resp = quarantine_impose_next_schedule_restriction($this->getFilterObj() , $date, $how);
return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETQUARANTINEFILTERS);
}
/**
 * sets the filter sender restriction
 * @return bool
 * @param $sender string the Sender to filter
 * @param $compareType type of comparison (equal , not equal)
 */
public function imposeSenderRestriction($sender, $compareType) {
    if (!$this) return false;
    switch (strtolower($compareType)) {
        case "equal":
            $how = 0;
        break;
        case "notequal":
            $how = 1;
        break;
        default:
            return false;
    }
    if (!is_resource($this->getFilterObj())) $this->startFilter();
    $resp = quarantine_impose_sender_restriction($this->getFilterObj() , $sender, $how);
    return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETQUARANTINEFILTERS);
}
/**
 * sets the filter recipient restriction
 * @return bool
 * @param $recipient string the Recipient to filter
 * @param $compareType string type of comparison (equal , not equal)
 */
public function imposeRecipientRestriction($recipient, $compareType = "equal") {
    if (!$this) return false;
    switch (strtolower($compareType)) {
        case "equal":
            $how = 0;
        break;
        case "notequal":
            $how = 1;
        break;
        default:
            return false;
    }
    if (!is_resource($this->getFilterObj())) $this->startFilter();
    $resp = quarantine_impose_recipient_restriction($this->getFilterObj() , $recipient, $how);
    return Debug::checkError($resp, 0, Debug::INFOERROR, Message::SETQUARANTINEFILTERS);
}
/**
 * applies a delete action to filtered emails
 * @return bool
 */
public function deleteFilteredEmails() {
    $resp = quarantine_apply_filter($this->getFilterObj() , $this->getQuarantineObj() , $this->getSessionObj() , 3);
    return Debug::checkError($resp, 0, Debug::INFOERROR, Message::QUARANTINEDELETEFILTERED);
}
/**
 * applies a delivery action to filtered emails
 * @return bool
 */
public function deliverFilteredEmails() {
    $resp = quarantine_apply_filter($this->getFilterObj() , $this->getQuarantineObj() , $this->getSessionObj() , 4);
    return Debug::checkError($resp, 0, Debug::INFOERROR, Message::QUARANTINEDELIVERFILTERED);
}
/**
 * returns an array with emails filtered by already set filters
 * @return array
 */
public function listFilteredEMails($action = "no action") {
    if (!$this) return false;
    if (!is_resource($this->getFilterObj())) return false;
    $list = array();
    $resp = quarantine_apply_filter($this->getFilterObj() , $this->getQuarantineObj() , $this->getSessionObj() , 0);
    if (!Debug::checkError($resp, 0, Debug::INFOERROR, Message::APPLYQUARANTINEFILTERS)) return false;
    $listObj = quarantine_filter_item_iterator_begin($this->getFilterObj());
    if (!Debug::checkError($listObj, "_p_quarantine_filter_item_iterator", Debug::INFOERROR, Message::LISTQUARANTINEFILTERS)) return false;
    while (quarantine_filter_item_iterator_has_value($listObj)) {
        $quarantineObj = quarantine_filter_item_iterator_value($listObj);
        unset($tmp);
        $tmp['id'] = quarantine_item_id_get($quarantineObj);
        $tmp['sender'] = quarantine_item_sender_get($quarantineObj);
        $tmp['status'] = quarantine_item_status_get($quarantineObj);
        $tmp['recipients'] = quarantine_item_recipients_get($quarantineObj);
        $tmp['size'] = quarantine_item_size_get($quarantineObj);
        $tmp['nextSchedule'] = quarantine_item_next_schedule_get($quarantineObj);
        array_push($list, $tmp);
        quarantine_filter_item_iterator_next($listObj);
    }
    quarantine_filter_item_iterator_destroy($listObj);
    return $list;
}
/**
 * this method tells Axigen to delete the mailId
 * @return bool
 * @param $mailID string the mailId to delete
 */
public function deleteQuarantineEMail($mailID) {
    if (!$this) return false;
    $resp = quarantine_delete_message_by_id($mailID, $this->getQuarantineObj() , $this->getSessionObj());
    return Debug::checkError($resp, 0, Debug::INFOERROR, Message::DELETEQUARANTINE);
}
/**
 * this method tells Axigen to delete the mailId
 * @return bool
 * @param $mailID string the mailId to delete
 */
public function deliverQuarantineEMail($mailID) {
    if (!$this) return false;
    $resp = quarantine_deliver_message_by_id($mailID, $this->getQuarantineObj() , $this->getSessionObj());
    return Debug::checkError($resp, 0, Debug::INFOERROR, Message::DELIVERQUARANTINE);
}
}
/** @} */ // end of group
?>
